@@ -1,16 +1,21 @@
 #!/usr/bin/env python3
 
 import json
+import sys
 
 from ruamel.yaml import YAML
 
 yaml = YAML(typ='safe')
 entries = list()
+native_only = sys.argv[1]
 
 with open('.github/data/distros.yml') as f:
     data = yaml.load(f)
 
 for arch in data['static_arches']:
+    if native_only == '1' and data['arch_data'][arch]['qemu']:
+        continue
+
     entries.append({
         'arch': arch,
         'runner': data['arch_data'][arch]['runner'],
