@@ -1,5 +1,6 @@
 #!/bin/sh
-
+# SPDX-License-Identifier: GPL-3.0-or-later
+#
 # Netdata updater utility
 #
 # Variables needed by script:
@@ -20,13 +21,6 @@
 #
 #  - TMPDIR (set to a usable temporary directory)
 #  - NETDATA_NIGHTLIES_BASEURL (set the base url for downloading the dist tarball)
-#
-# Copyright: 2018-2023 Netdata Inc.
-# SPDX-License-Identifier: GPL-3.0-or-later
-#
-# Author: Paweł Krupa <paulfantom@gmail.com>
-# Author: Pavlos Emm. Katsoulakis <paul@netdata.cloud>
-# Author: Austin S. Hemmelgarn <austin@netdata.cloud>
 
 # Next unused error code: U001D
 
@@ -117,18 +111,47 @@ is_integer () {
   esac
 }
 
-issystemd() {
-  # if the directory /lib/systemd/system OR /usr/lib/systemd/system (SLES 12.x) does not exit, it is not systemd
-  if [ ! -d /lib/systemd/system ] && [ ! -d /usr/lib/systemd/system ]; then
-    return 1
+safe_pidof() {
+  pidof_cmd="$(command -v pidof 2> /dev/null)"
+  if [ -n "${pidof_cmd}" ]; then
+    ${pidof_cmd} "${@}"
+    return $?
+  else
+    ps -acxo pid,comm |
+      sed "s/^ *//g" |
+      grep netdata |
+      cut -d ' ' -f 1
+    return $?
   fi
+}
 
+issystemd() {
   # if there is no systemctl command, it is not systemd
   systemctl=$(command -v systemctl 2> /dev/null)
   if [ -z "${systemctl}" ] || [ ! -x "${systemctl}" ]; then
     return 1
   fi
 
+  # Check the output of systemctl is-system-running.
+  # If this reports 'offline', it’s not systemd. If it reports 'unknown'
+  # or nothing at all (which indicates the command is not supported), it
+  # may or may not be systemd, so continue to other checks. If it reports
+  # anything else, it is systemd.
+  #
+  # This may return a non-zero exit status in cases when it actually
+  # succeeded for our purposes (notably, if the state is `degraded`),
+  # so we need to toggle set -e off here.
+  set +e
+  systemd_state="$(systemctl is-system-running)"
+  set -e
+
+  case "${systemd_state}" in
+    offline) return 1 ;;
+    unknown) : ;;
+    "") : ;;
+    *) return 0 ;;
+  esac
+
   # if pid 1 is systemd, it is systemd
   [ "$(basename "$(readlink /proc/1/exe)" 2> /dev/null)" = "systemd" ] && return 0
 
@@ -149,6 +172,51 @@ issystemd() {
   return 1
 }
 
+systemd_unit_exists() {
+  if systemctl list-unit-files "${1}" 2>&1 | tail -n 1 | grep -qv '^0 '; then
+    return 0
+  else
+    return 1
+  fi
+}
+
+# shellcheck disable=SC2009
+running_under_anacron() {
+    pid="${1:-$$}"
+    iter="${2:-0}"
+
+    [ "${iter}" -gt 50 ] && return 1
+
+    if [ "$(uname -s)" = "Linux" ] && [ -r "/proc/${pid}/stat" ]; then
+        ppid="$(cut -f 4 -d ' ' "/proc/${pid}/stat")"
+        if [ -n "${ppid}" ]; then
+            # The below case accounts for the hidepid mount option for procfs, as well as setups with LSM
+            [ ! -r "/proc/${ppid}/comm" ] && return 1
+
+            [ "${ppid}" -eq "${pid}" ] && return 1
+
+            grep -q anacron "/proc/${ppid}/comm" && return 0
+
+            running_under_anacron "${ppid}" "$((iter + 1))"
+
+            return "$?"
+        fi
+    else
+        ppid="$(ps -o pid= -o ppid= 2>/dev/null | grep -e "^ *${pid}" | xargs | cut -f 2 -d ' ')"
+        if [ -n "${ppid}" ]; then
+            [ "${ppid}" -eq "${pid}" ] && return 1
+
+            ps -o pid= -o command= 2>/dev/null | grep -e "^ *${ppid}" | grep -q anacron && return 0
+
+            running_under_anacron "${ppid}" "$((iter + 1))"
+
+            return "$?"
+        fi
+    fi
+
+    return 1
+}
+
 _get_intervaldir() {
   if [ -d /etc/cron.daily ]; then
     echo /etc/cron.daily
@@ -247,11 +315,17 @@ enable_netdata_updater() {
   case "${updater_type}" in
     "systemd")
       if issystemd; then
-        systemctl enable netdata-updater.timer
+        if systemd_unit_exists netdata-updater.timer; then
+          systemctl enable netdata-updater.timer
+          systemctl start netdata-updater.timer
 
-        info "Auto-updating has been ENABLED using a systemd timer unit.\n"
-        info "If the update process fails, the failure will be logged to the systemd journal just like a regular service failure."
-        info "Successful updates should produce empty logs."
+          info "Auto-updating has been ENABLED using a systemd timer unit.\n"
+          info "If the update process fails, the failure will be logged to the systemd journal just like a regular service failure."
+          info "Successful updates should produce empty logs."
+        else
+          error "Systemd-based auto-update scheduling requested, but the required timer unit does not exist. Auto-updates have NOT been enabled."
+          return 1
+        fi
       else
         error "Systemd-based auto-update scheduling requested, but this does not appear to be a systemd system. Auto-updates have NOT been enabled."
         return 1
@@ -272,7 +346,7 @@ enable_netdata_updater() {
     "crontab")
       if [ -d "/etc/cron.d" ]; then
         [ -f "/etc/cron.d/netdata-updater" ] && rm -f "/etc/cron.d/netdata-updater"
-        install -p -m 0644 -o 0 -g 0 "${NETDATA_PREFIX}/usr/lib/system/cron/netdata-updater-daily" "/etc/cron.d/netdata-updater-daily"
+        install -p -m 0644 -o 0 -g 0 "${NETDATA_PREFIX}/usr/lib/netdata/system/cron/netdata-updater-daily" "/etc/cron.d/netdata-updater-daily"
 
         info "Auto-updating has been ENABLED through cron, using a crontab at /etc/cron.d/netdata-updater\n"
         info "If the update process fails and you have email notifications set up correctly for cron on this system, you should receive an email notification of the failure."
@@ -291,8 +365,9 @@ enable_netdata_updater() {
 }
 
 disable_netdata_updater() {
-  if issystemd && ( systemctl list-units --full -all | grep -Fq "netdata-updater.timer" ) ; then
+  if issystemd && systemd_unit_exists "netdata-updater.timer" ; then
     systemctl disable netdata-updater.timer
+    systemctl stop netdata-updater.timer
   fi
 
   if [ -d /etc/cron.daily ]; then
@@ -315,6 +390,91 @@ disable_netdata_updater() {
   return 0
 }
 
+auto_update_status() {
+  case "$(_get_scheduler_type)" in
+    systemd) info "The default auto-update scheduling method for this system is: systemd timer units" ;;
+    crontab) info "The default auto-update scheduling method for this system is: drop-in crontab" ;;
+    interval) info "The default auto-update scheduling method for this system is: drop-in periodic script" ;;
+    *) info "No recognized auto-update scheduling method found" ; return ;;
+  esac
+
+  duplicate=""
+  enabled=""
+
+  if issystemd; then
+    if systemd_unit_exists "netdata-updater.timer"; then
+      if systemctl is-enabled netdata-updater.timer; then
+        info "Auto-updates using a systemd timer unit are ENABLED"
+        enabled="systemd"
+      else
+        info "Auto-updates using a systemd timer unit are DISABLED"
+      fi
+    else
+      info "Auto-updates using a systemd timer unit are NOT SUPPORTED due to: Required unit files not installed"
+    fi
+  else
+    info "Auto-updates using a systemd timer unit are NOT SUPPORTED due to: Systemd not present"
+  fi
+
+  interval_found=""
+
+  if [ -d /etc/cron.daily ]; then
+    interval_found="1"
+
+    if [ -x /etc/cron.daily/netdata-updater.sh ] || [ -x /etc/cron.daily/netdata-updater ]; then
+      info "Auto-updates using a drop-in periodic script in /etc/cron.daily are ENABLED"
+
+      if [ -n "${enabled}" ]; then
+        duplicate="1"
+      else
+        enabled="cron.daily"
+      fi
+    else
+      info "Auto-updates using a drop-in periodic script in /etc/cron.daily are DISABLED"
+    fi
+  else
+    info "Auto-updates using a drop-in periodic script in /etc/cron.daily are NOT SUPPORTED: due to: Directory does not exist"
+  fi
+
+  if [ -d /etc/periodic/daily ]; then
+    if [ -x /etc/periodic/daily/netdata-updater.sh ] || [ -x /etc/periodic/daily/netdata-updater ]; then
+      info "Auto-updates using a drop-in periodic script in /etc/periodic/daily are ENABLED"
+
+      if [ -n "${enabled}" ]; then
+        duplicate="1"
+      else
+        enabled="periodic/daily"
+      fi
+    else
+      if [ -z "${interval_found}" ]; then
+        info "Auto-updates using a drop-in periodic script in /etc/periodic/daily are DISABLED"
+      fi
+    fi
+  elif [ -z "${interval_found}" ]; then
+    info "Auto-updates using a drop-in periodic script in /etc/periodic/daily are NOT SUPPORTED due to: Directory does not exist"
+  fi
+
+  if [ -d /etc/cron.d ]; then
+    if [ -f /etc/cron.d/netdata-updater ] || [ -f /etc/cron.d/netdata-updater-daily ]; then
+      info "Auto-updates using a drop-in crontab are ENABLED"
+
+      if [ -n "${enabled}" ]; then
+        duplicate="1"
+      else
+        enabled="cron.d"
+      fi
+    else
+      info "Auto-updates using a drop-in crontab are DISABLED"
+    fi
+  else
+    info "Auto-updates using a drop-in crontab are NOT SUPPORTED due to: Directory does not exist"
+  fi
+
+  if [ -n "${duplicate}" ]; then
+    warning "More than one method of auto-updates is enabled! Please disable and re-enable auto-updates to correct this."
+  fi
+}
+
 str_in_list() {
   printf "%s\n" "${2}" | tr ' ' "\n" | grep -qE "^${1}\$"
   return $?
@@ -363,28 +523,29 @@ _cannot_use_tmpdir() {
   return "${ret}"
 }
 
-create_tmp_directory() {
+create_exec_tmp_directory() {
   if [ -n "${NETDATA_TMPDIR_PATH}" ]; then
     echo "${NETDATA_TMPDIR_PATH}"
-  else
-    if [ -z "${NETDATA_TMPDIR}" ] || _cannot_use_tmpdir "${NETDATA_TMPDIR}" ; then
-      if [ -z "${TMPDIR}" ] || _cannot_use_tmpdir "${TMPDIR}" ; then
-        if _cannot_use_tmpdir /tmp ; then
-          if _cannot_use_tmpdir "${PWD}" ; then
-            fatal "Unable to find a usable temporary directory. Please set \$TMPDIR to a path that is both writable and allows execution of files and try again." U0003
-          else
-            TMPDIR="${PWD}"
-          fi
-        else
-          TMPDIR="/tmp"
-        fi
-      fi
-    else
-      TMPDIR="${NETDATA_TMPDIR}"
-    fi
-
-    mktemp -d -t netdata-updater-XXXXXXXXXX
+    return
   fi
+
+  root_dir=""
+
+  if [ -n "${NETDATA_TMPDIR}" ] && ! _cannot_use_tmpdir "${NETDATA_TMPDIR}"; then
+    root_dir="${NETDATA_TMPDIR}"
+  elif [ -n "${TMPDIR}" ] && ! _cannot_use_tmpdir "${TMPDIR}"; then
+    root_dir="${TMPDIR}"
+  elif ! _cannot_use_tmpdir /tmp; then
+    root_dir="/tmp"
+  elif ! _cannot_use_tmpdir "${PWD}"; then
+    root_dir="${PWD}"
+  else
+    fatal "Unable to find a usable temporary directory. Please set \$TMPDIR to a path that is both writable and allows execution of files and try again." U0003
+  fi
+
+  TMPDIR="${root_dir}"
+
+  mktemp -d -p "${root_dir}" -t netdata-updater-XXXXXXXXXX
 }
 
 check_for_curl() {
@@ -396,15 +557,42 @@ check_for_curl() {
 _safe_download() {
   url="${1}"
   dest="${2}"
+  succeeded=0
+  checked=0
+
+  if echo "${url}" | grep -Eq "^file:///"; then
+    run cp "${url#file://}" "${dest}" || return 1
+    return 0
+  fi
 
   check_for_curl
 
   if [ -n "${curl}" ]; then
-    "${curl}" -fsSL --connect-timeout 10 --retry 3 "${url}" > "${dest}"
-    return $?
-  elif command -v wget > /dev/null 2>&1; then
-    wget -T 15 -O - "${url}" > "${dest}"
-    return $?
+    checked=1
+
+    if "${curl}" -fsSL --connect-timeout 10 --retry 3 "${url}" > "${dest}"; then
+      succeeded=1
+    else
+      rm -f "${dest}"
+    fi
+  fi
+
+  if [ "${succeeded}" -eq 0 ]; then
+    if command -v wget > /dev/null 2>&1; then
+      checked=1
+
+      if wget -T 15 -O - "${url}" > "${dest}"; then
+        succeeded=1
+      else
+        rm -f "${dest}"
+      fi
+    fi
+  fi
+
+  if [ "${succeeded}" -eq 1 ]; then
+    return 0
+  elif [ "${checked}" -eq 1 ]; then
+    return 1
   else
     return 255
   fi
@@ -432,13 +620,21 @@ get_netdata_latest_tag() {
   check_for_curl
 
   if [ -n "${curl}" ]; then
-    tag=$("${curl}" "${url}" -s -L -I -o /dev/null -w '%{url_effective}' | grep -Eom 1 '[^/]*/?$')
-  elif command -v wget >/dev/null 2>&1; then
-    tag=$(wget -S -O /dev/null "${url}" 2>&1 | grep -m 1 Location | grep -Eo '[^/]*/?$')
-  else
+    tag=$("${curl}" "${url}" -s -L -I -o /dev/null -w '%{url_effective}')
+  fi
+
+  if [ -z "${tag}" ]; then
+    if command -v wget >/dev/null 2>&1; then
+      tag=$(wget -S -O /dev/null "${url}" 2>&1 | grep Location)
+    fi
+  fi
+
+  if [ -z "${tag}" ]; then
     fatal "I need curl or wget to proceed, but neither of them are available on this system." U0006
   fi
 
+  tag="$(echo "${tag}" | grep -Eom 1 '[^/]*/?$')"
+
   # Fallback case for simpler local testing.
   if echo "${tag}" | grep -Eq 'latest/?$'; then
     if _safe_download "${url}/latest-version.txt" ./ndupdate-version.txt; then
@@ -460,15 +656,33 @@ get_netdata_latest_tag() {
 newer_commit_date() {
   info "Checking if a newer version of the updater script is available."
 
+  ndtmpdir="$(create_exec_tmp_directory)"
+  commit_check_file="${ndtmpdir}/latest-commit.json"
   commit_check_url="https://api.github.com/repos/netdata/netdata/commits?path=packaging%2Finstaller%2Fnetdata-updater.sh&page=1&per_page=1"
-  python_version_check="from __future__ import print_function;import sys,json;data = json.load(sys.stdin);print(data[0]['commit']['committer']['date'] if isinstance(data, list) else '')"
+  python_version_check="
+from __future__ import print_function
+import sys, json
+
+try:
+    data = json.load(sys.stdin)
+except:
+    print('')
+else:
+    print(data[0]['commit']['committer']['date'] if isinstance(data, list) and data else '')
+"
+
+  _safe_download "${commit_check_url}" "${commit_check_file}"
 
   if command -v jq > /dev/null 2>&1; then
-    commit_date="$(_safe_download "${commit_check_url}" /dev/stdout | jq '.[0].commit.committer.date' 2>/dev/null | tr -d '"')"
+    commit_date="$(jq '.[0].commit.committer.date' 2>/dev/null < "${commit_check_file}" | tr -d '"')"
   elif command -v python > /dev/null 2>&1;then
-    commit_date="$(_safe_download "${commit_check_url}" /dev/stdout | python -c "${python_version_check}")"
+    commit_date="$(python -c "${python_version_check}" < "${commit_check_file}")"
   elif command -v python3 > /dev/null 2>&1;then
-    commit_date="$(_safe_download "${commit_check_url}" /dev/stdout | python3 -c "${python_version_check}")"
+    commit_date="$(python3 -c "${python_version_check}" < "${commit_check_file}")"
+  fi
+
+  if [ -z "${NETDATA_TMPDIR_PATH}" ]; then
+    rm -rf "${ndtmpdir}" >&3 2>&3
   fi
 
   if [ -z "${commit_date}" ] ; then
@@ -496,15 +710,19 @@ self_update() {
   if [ -z "${NETDATA_NO_UPDATER_SELF_UPDATE}" ] && newer_commit_date; then
     info "Downloading newest version of updater script."
 
-    ndtmpdir=$(create_tmp_directory)
+    ndtmpdir=$(create_exec_tmp_directory)
     cd "$ndtmpdir" || exit 1
 
     if _safe_download "https://raw.githubusercontent.com/netdata/netdata/master/packaging/installer/netdata-updater.sh" ./netdata-updater.sh; then
       chmod +x ./netdata-updater.sh || exit 1
       export ENVIRONMENT_FILE="${ENVIRONMENT_FILE}"
-      force_update=""
-      [ "$NETDATA_FORCE_UPDATE" = "1" ] && force_update="--force-update"
-      exec ./netdata-updater.sh --not-running-from-cron --no-updater-self-update "$force_update" --tmpdir-path "$(pwd)"
+
+      cmd="./netdata-updater.sh --not-running-from-cron --no-updater-self-update"
+      [ "$NETDATA_FORCE_UPDATE" = "1" ] && cmd="$cmd --force-update"
+      [ "$INTERACTIVE" = "0" ] && cmd="$cmd --non-interactive"
+      cmd="$cmd --tmpdir-path $(pwd)"
+
+      exec $cmd
     else
       error "Failed to download newest version of updater script, continuing with current version."
     fi
@@ -630,7 +848,11 @@ set_tarball_urls() {
     fi
   fi
 
-  if [ "$1" = "stable" ]; then
+  if [ -n "${NETDATA_OFFLINE_INSTALL_SOURCE}" ]; then
+    path="$(cd "${NETDATA_OFFLINE_INSTALL_SOURCE}" || exit 1; pwd)"
+    export NETDATA_TARBALL_URL="file://${path}/${filename}"
+    export NETDATA_TARBALL_CHECKSUM_URL="file://${path}/sha256sums.txt"
+  elif [ "$1" = "stable" ]; then
     latest="$(get_netdata_latest_tag "${NETDATA_STABLE_BASE_URL}")"
     export NETDATA_TARBALL_URL="${NETDATA_STABLE_BASE_URL}/download/$latest/${filename}"
     export NETDATA_TARBALL_CHECKSUM_URL="${NETDATA_STABLE_BASE_URL}/download/$latest/sha256sums.txt"
@@ -645,7 +867,7 @@ update_build() {
   [ -z "${logfile}" ] && info "Running on a terminal - (this script also supports running headless from crontab)"
 
   RUN_INSTALLER=0
-  ndtmpdir=$(create_tmp_directory)
+  ndtmpdir=$(create_exec_tmp_directory)
   cd "$ndtmpdir" || fatal "Failed to change current working directory to ${ndtmpdir}" U0016
 
   install_build_dependencies
@@ -744,7 +966,7 @@ update_build() {
 }
 
 update_static() {
-  ndtmpdir="$(create_tmp_directory)"
+  ndtmpdir="$(create_exec_tmp_directory)"
   PREVDIR="$(pwd)"
 
   info "Entering ${ndtmpdir}"
@@ -820,6 +1042,12 @@ update_binpkg() {
       cloudlinux|almalinux|centos-stream|rocky|rhel)
         DISTRO_COMPAT_NAME="centos"
         ;;
+      raspbian)
+        SYSARCH="$(uname -m)"
+        if [ "$SYSARCH" = "armv7l" ] || [ "$SYSARCH" = "aarch64" ]; then
+          DISTRO_COMPAT_NAME="debian"
+        fi
+        ;;
       *)
         DISTRO_COMPAT_NAME="unknown"
         ;;
@@ -1014,6 +1242,10 @@ while [ -n "${1}" ]; do
     --force-update) NETDATA_FORCE_UPDATE=1 ;;
     --non-interactive) INTERACTIVE=0 ;;
     --interactive) INTERACTIVE=1 ;;
+    --offline-install-source)
+      NETDATA_OFFLINE_INSTALL_SOURCE="${2}"
+      shift 1
+      ;;
     --tmpdir-path)
       NETDATA_TMPDIR_PATH="${2}"
       shift 1
@@ -1026,12 +1258,28 @@ while [ -n "${1}" ]; do
       disable_netdata_updater
       exit $?
       ;;
+    --auto-update-status)
+      auto_update_status
+      exit 0
+      ;;
     *) fatal "Unrecognized option ${1}" U001A ;;
   esac
 
   shift 1
 done
 
+if [ -n "${NETDATA_OFFLINE_INSTALL_SOURCE}" ]; then
+  NETDATA_NO_UPDATER_SELF_UPDATE=1
+  NETDATA_UPDATER_JITTER=0
+  NETDATA_FORCE_UPDATE=1
+fi
+
+# If we seem to be running under anacron, act as if we’re not running from cron.
+# This is mostly to disable jitter, which should not be needed when run from anacron.
+if running_under_anacron; then
+  NETDATA_NOT_RUNNING_FROM_CRON="${NETDATA_NOT_RUNNING_FROM_CRON:-1}"
+fi
+
 # Random sleep to alleviate stampede effect of Agents upgrading
 # and disconnecting/reconnecting at the same time (or near to).
 # But only we're not a controlling terminal (tty)
