@@ -2,7 +2,7 @@
 
 #include "aclk_query.h"
 #include "aclk_tx_msgs.h"
-#include "../../web/server/web_client_cache.h"
+#include "web/server/web_client_cache.h"
 
 static HTTP_ACL default_aclk_http_acl = HTTP_ACL_ALL_FEATURES;
 
@@ -19,7 +19,7 @@ static struct pending_req_list *pending_req_list_head = NULL;
 static SPINLOCK pending_req_list_lock = SPINLOCK_INITIALIZER;
 
 void aclk_config_get_query_scope(void) {
-    const char *s = config_get(CONFIG_SECTION_CLOUD, "scope", "full");
+    const char *s = inicfg_get(&netdata_config, CONFIG_SECTION_CLOUD, "scope", "full");
     if(strcmp(s, "license manager") == 0)
         default_aclk_http_acl = HTTP_ACL_ACLK_LICENSE_MANAGER;
 }
@@ -66,6 +66,17 @@ void pending_req_list_rm(const char *msg_id)
     spinlock_unlock(&pending_req_list_lock);
 }
 
+void mark_pending_req_cancel_all()
+{
+    spinlock_lock(&pending_req_list_lock);
+    struct pending_req_list *curr = pending_req_list_head;
+    while (curr) {
+        curr->canceled = 1;
+        curr = curr->next;
+    }
+    spinlock_unlock(&pending_req_list_lock);
+}
+
 int mark_pending_req_cancelled(const char *msg_id)
 {
     uint32_t hash = simple_hash(msg_id);
