@@ -338,6 +338,9 @@ void read_cgroup_plugin_configuration() {
 
                        // ----------------------------------------------------------------
 
+                       " !/machine.slice/*/.control "
+                       " !/machine.slice/*/payload* "
+                       " !/machine.slice/*/supervisor "
                        " /machine.slice/*.service "           // #3367 systemd-nspawn
 
                        // ----------------------------------------------------------------
@@ -1380,6 +1383,10 @@ void *cgroups_main(void *ptr) {
         goto exit;
     }
 
+    // we register this only on localhost
+    // for the other nodes, the origin server should register it
+    cgroup_netdev_link_init();
+
     discovery_thread.exited = 0;
 
     if (uv_mutex_init(&discovery_thread.mutex)) {
@@ -1397,10 +1404,6 @@ void *cgroups_main(void *ptr) {
         goto exit;
     }
 
-    // we register this only on localhost
-    // for the other nodes, the origin server should register it
-    cgroup_netdev_link_init();
-
     rrd_function_add_inline(localhost, NULL, "containers-vms", 10,
                             RRDFUNCTIONS_PRIORITY_DEFAULT / 2, RRDFUNCTIONS_VERSION_DEFAULT,
                             RRDFUNCTIONS_CGTOP_HELP,
@@ -1459,6 +1462,8 @@ void *cgroups_main(void *ptr) {
         uv_mutex_unlock(&cgroup_root_mutex);
     }
 
+    // uv_thread_join(&discovery_thread.thread);
+
 exit:
     return NULL;
 }
