@@ -1256,6 +1256,12 @@ void *libsensors_thread(void *ptr __maybe_unused) {
         usec_t ended_ut = now_monotonic_usec();
         usec_t average_ut = (ended_ut - started_ut) / samples;
 
+        if(average_ut < 1)
+            average_ut = 1;
+
+        if(max_ut < 1)
+            max_ut = 1;
+
         // List of valid intervals in seconds (divisors and multiples of 60)
         static const int valid_update_every_intervals[] = {1, 2, 3, 4, 5, 6, 10, 12, 15, 20, 30, 60, 120, 180, 240, 300, 600, 900, 1200, 1800, 3600};
 
