@@ -19,16 +19,9 @@
 #include <ctype.h>
 #include <dirent.h>
 
-// From libnetdata.h
-#include "libnetdata/threads/threads.h"
-#include "libnetdata/locks/locks.h"
-#include "libnetdata/avl/avl.h"
-#include "libnetdata/clocks/clocks.h"
-#include "libnetdata/config/appconfig.h"
 #include "libbpf_api/ebpf.h"
-#include "libnetdata/procfile/procfile.h"
+
 #include "collectors/cgroups.plugin/sys_fs_cgroup.h"
-#include "daemon/main.h"
 
 #include "ebpf_apps.h"
 #include "ebpf_functions.h"
@@ -106,9 +99,9 @@ typedef struct netdata_ebpf_judy_pid {
     ARAL *pid_table;
 
     // Index for PIDs
-    struct {                            // support for multiple indexing engines
-        Pvoid_t JudyLArray;            // the hash table
-        RW_SPINLOCK rw_spinlock;        // protect the index
+    struct {                     // support for multiple indexing engines
+        Pvoid_t JudyLArray;      // the hash table
+        RW_SPINLOCK rw_spinlock; // protect the index
     } index;
 } netdata_ebpf_judy_pid_t;
 
@@ -116,9 +109,9 @@ typedef struct netdata_ebpf_judy_pid_stats {
     char *cmdline;
 
     // Index for Socket timestamp
-    struct {                            // support for multiple indexing engines
-        Pvoid_t JudyLArray;            // the hash table
-        RW_SPINLOCK rw_spinlock;        // protect the index
+    struct {                     // support for multiple indexing engines
+        Pvoid_t JudyLArray;      // the hash table
+        RW_SPINLOCK rw_spinlock; // protect the index
     } socket_stats;
 } netdata_ebpf_judy_pid_stats_t;
 
@@ -159,6 +152,7 @@ typedef struct ebpf_tracepoint {
 #define NETDATA_EBPF_THREADS "ebpf_threads"
 #define NETDATA_EBPF_LIFE_TIME "ebpf_life_time"
 #define NETDATA_EBPF_LOAD_METHOD "ebpf_load_methods"
+#define NETDATA_EBPF_IPC_USAGE "ebpf_ipc_usage"
 #define NETDATA_EBPF_KERNEL_MEMORY "ebpf_kernel_memory"
 #define NETDATA_EBPF_HASH_TABLES_LOADED "ebpf_hash_tables_count"
 #define NETDATA_EBPF_HASH_TABLES_PER_CORE "ebpf_hash_tables_per_core"
@@ -182,10 +176,7 @@ typedef struct ebpf_tracepoint {
 
 #define EBPF_DEFAULT_UPDATE_EVERY 10
 
-enum ebpf_algorithms_list {
-    NETDATA_EBPF_ABSOLUTE_IDX,
-    NETDATA_EBPF_INCREMENTAL_IDX
-};
+enum ebpf_algorithms_list { NETDATA_EBPF_ABSOLUTE_IDX, NETDATA_EBPF_INCREMENTAL_IDX };
 
 // Threads
 void *ebpf_process_thread(void *ptr);
@@ -203,42 +194,45 @@ extern int process_pid_fd;
 extern pthread_mutex_t collect_data_mutex;
 
 // Common functions
-void ebpf_global_labels(netdata_syscall_stat_t *is,
-                               netdata_publish_syscall_t *pio,
-                               char **dim,
-                               char **name,
-                               int *algorithm,
-                               int end);
+void ebpf_global_labels(
+    netdata_syscall_stat_t *is,
+    netdata_publish_syscall_t *pio,
+    char **dim,
+    char **name,
+    int *algorithm,
+    int end);
 
-void ebpf_write_chart_cmd(char *type,
-                                 char *id,
-                                 char *suffix,
-                                 char *title,
-                                 char *units,
-                                 char *family,
-                                 char *charttype,
-                                 char *context,
-                                 int order,
-                                 int update_every,
-                                 char *module);
+void ebpf_write_chart_cmd(
+    char *type,
+    char *id,
+    char *suffix,
+    char *title,
+    char *units,
+    char *family,
+    char *charttype,
+    char *context,
+    int order,
+    int update_every,
+    char *module);
 
 void ebpf_write_global_dimension(char *name, char *id, char *algorithm);
 
 void ebpf_create_global_dimension(void *ptr, int end);
 
-void ebpf_create_chart(char *type,
-                              char *id,
-                              char *title,
-                              char *units,
-                              char *family,
-                              char *context,
-                              char *charttype,
-                              int order,
-                              void (*ncd)(void *, int),
-                              void *move,
-                              int end,
-                              int update_every,
-                              char *module);
+void ebpf_create_chart(
+    char *type,
+    char *id,
+    char *title,
+    char *units,
+    char *family,
+    char *context,
+    char *charttype,
+    int order,
+    void (*ncd)(void *, int),
+    void *move,
+    int end,
+    int update_every,
+    char *module);
 
 void write_chart_dimension(char *dim, long long value);
 
@@ -246,8 +240,7 @@ void write_count_chart(char *name, char *family, netdata_publish_syscall_t *move
 
 void write_err_chart(char *name, char *family, netdata_publish_syscall_t *move, int end);
 
-void write_io_chart(char *chart, char *family, char *dwrite, long long vwrite,
-                           char *dread, long long vread);
+void write_io_chart(char *chart, char *family, char *dwrite, long long vwrite, char *dread, long long vread);
 
 /**
  * Create Chart labels
@@ -333,15 +326,29 @@ void ebpf_cachestat_create_apps_charts(struct ebpf_module *em, void *root);
 void ebpf_one_dimension_write_charts(char *family, char *chart, char *dim, long long v1);
 collected_number get_value_from_structure(char *basis, size_t offset);
 void ebpf_update_pid_table(ebpf_local_maps_t *pid, ebpf_module_t *em);
-void ebpf_write_chart_obsolete(char *type, char *id, char *suffix, char *title, char *units, char *family,
-                                      char *charttype, char *context, int order, int update_every);
+void ebpf_write_chart_obsolete(
+    char *type,
+    char *id,
+    char *suffix,
+    char *title,
+    char *units,
+    char *family,
+    char *charttype,
+    char *context,
+    int order,
+    int update_every);
 void write_histogram_chart(char *family, char *name, const netdata_idx_t *hist, char **dimensions, uint32_t end);
 void ebpf_update_disabled_plugin_stats(ebpf_module_t *em);
 ARAL *ebpf_allocate_pid_aral(char *name, size_t size);
 void ebpf_unload_legacy_code(struct bpf_object *objects, struct bpf_link **probe_links);
 
-void ebpf_read_global_table_stats(netdata_idx_t *stats, netdata_idx_t *values, int map_fd,
-                                  int maps_per_core, uint32_t begin, uint32_t end);
+void ebpf_read_global_table_stats(
+    netdata_idx_t *stats,
+    netdata_idx_t *values,
+    int map_fd,
+    int maps_per_core,
+    uint32_t begin,
+    uint32_t end);
 void **ebpf_judy_insert_unsafe(PPvoid_t arr, Word_t key);
 netdata_ebpf_judy_pid_stats_t *ebpf_get_pid_from_judy_unsafe(PPvoid_t judy_array, uint32_t pid);
 
@@ -355,7 +362,8 @@ extern ebpf_sync_syscalls_t local_syscalls[];
 extern bool ebpf_plugin_exit;
 extern uint64_t collect_pids;
 
-static inline bool ebpf_plugin_stop(void) {
+static inline bool ebpf_plugin_stop(void)
+{
     return ebpf_plugin_exit || nd_thread_signaled_to_cancel();
 }
 
