@@ -17,7 +17,8 @@ void ebpf_aral_init(void)
 {
     size_t max_elements = NETDATA_EBPF_ALLOC_MAX_PID;
     if (max_elements < NETDATA_EBPF_ALLOC_MIN_ELEMENTS) {
-        netdata_log_error("Number of elements given is too small, adjusting it for %d", NETDATA_EBPF_ALLOC_MIN_ELEMENTS);
+        netdata_log_error(
+            "Number of elements given is too small, adjusting it for %d", NETDATA_EBPF_ALLOC_MIN_ELEMENTS);
         max_elements = NETDATA_EBPF_ALLOC_MIN_ELEMENTS;
     }
 
@@ -122,7 +123,8 @@ void clean_apps_groups_target(struct ebpf_target *agrt)
  *
  * @return It returns the target on success and NULL otherwise
  */
-struct ebpf_target *get_apps_groups_target(struct ebpf_target **agrt, const char *id, struct ebpf_target *target, const char *name)
+struct ebpf_target *
+get_apps_groups_target(struct ebpf_target **agrt, const char *id, struct ebpf_target *target, const char *name)
 {
     int tdebug = 0, thidden = target ? target->hidden : 0, ends_with = 0;
     const char *nid = id;
@@ -164,8 +166,10 @@ struct ebpf_target *get_apps_groups_target(struct ebpf_target **agrt, const char
 
     if (target && target->target)
         fatal(
-            "Internal Error: request to link process '%s' to target '%s' which is linked to target '%s'", id,
-            target->id, target->target->id);
+            "Internal Error: request to link process '%s' to target '%s' which is linked to target '%s'",
+            id,
+            target->id,
+            target->target->id);
 
     w = callocz(1, sizeof(struct ebpf_target));
     strncpyz(w->id, nid, EBPF_MAX_NAME);
@@ -312,20 +316,19 @@ SPINLOCK ebpf_pid_spinlock = SPINLOCK_INITIALIZER;
 void ebpf_pid_del(pid_t pid)
 {
     spinlock_lock(&ebpf_pid_spinlock);
-    (void) JudyLDel(&ebpf_pid_judyL, (Word_t) pid, PJE0);
+    (void)JudyLDel(&ebpf_pid_judyL, (Word_t)pid, PJE0);
     spinlock_unlock(&ebpf_pid_spinlock);
 }
 
 static ebpf_pid_data_t *ebpf_find_pid_data_unsafe(pid_t pid)
 {
     ebpf_pid_data_t *pid_data = NULL;
-    Pvoid_t *Pvalue = JudyLGet(ebpf_pid_judyL, (Word_t) pid, PJE0);
+    Pvoid_t *Pvalue = JudyLGet(ebpf_pid_judyL, (Word_t)pid, PJE0);
     if (Pvalue)
         pid_data = *Pvalue;
     return pid_data;
 }
 
-
 ebpf_pid_data_t *ebpf_find_pid_data(pid_t pid)
 {
     spinlock_lock(&ebpf_pid_spinlock);
@@ -339,7 +342,7 @@ ebpf_pid_data_t *ebpf_find_or_create_pid_data(pid_t pid)
     spinlock_lock(&ebpf_pid_spinlock);
     ebpf_pid_data_t *pid_data = ebpf_find_pid_data_unsafe(pid);
     if (!pid_data) {
-        Pvoid_t *Pvalue = JudyLIns(&ebpf_pid_judyL, (Word_t) pid, PJE0);
+        Pvoid_t *Pvalue = JudyLIns(&ebpf_pid_judyL, (Word_t)pid, PJE0);
         internal_fatal(!Pvalue || Pvalue == PJERR, "EBPF: pid judy array");
         if (likely(!*Pvalue))
             *Pvalue = pid_data = callocz(1, sizeof(*pid_data));
@@ -352,20 +355,19 @@ ebpf_pid_data_t *ebpf_find_or_create_pid_data(pid_t pid)
 }
 
 //ebpf_pid_data_t *ebpf_pids = NULL;            // to avoid allocations, we pre-allocate the entire pid space.
-ebpf_pid_data_t *ebpf_pids_link_list = NULL;  // global list of all processes running
+ebpf_pid_data_t *ebpf_pids_link_list = NULL; // global list of all processes running
 
-size_t ebpf_all_pids_count = 0; // the number of processes running read from /proc
+size_t ebpf_all_pids_count = 0;        // the number of processes running read from /proc
 size_t ebpf_hash_table_pids_count = 0; // the number of tasks in our hash tables
 
-struct ebpf_target
-    *apps_groups_default_target = NULL, // the default target
-    *apps_groups_root_target = NULL,    // apps_groups.conf defined
-    *users_root_target = NULL,          // users
-    *groups_root_target = NULL;         // user groups
+struct ebpf_target *apps_groups_default_target = NULL, // the default target
+    *apps_groups_root_target = NULL,                   // apps_groups.conf defined
+        *users_root_target = NULL,                     // users
+            *groups_root_target = NULL;                // user groups
 
 size_t apps_groups_targets_count = 0; // # of apps_groups.conf targets
 
-int pids_fd[EBPF_PIDS_END_IDX];
+int pids_fd[NETDATA_EBPF_PIDS_END_IDX];
 
 // ----------------------------------------------------------------------------
 // internal counters
@@ -435,8 +437,10 @@ static inline void assign_target_to_pid(ebpf_pid_data_t *p)
         if (unlikely(
                 ((!w->starts_with && !w->ends_with && w->comparehash == hash && !strcmp(w->compare, p->comm)) ||
                  (w->starts_with && !w->ends_with && !strncmp(w->compare, p->comm, w->comparelen)) ||
-                 (!w->starts_with && w->ends_with && pclen >= w->comparelen && !strcmp(w->compare, &p->comm[pclen - w->comparelen])) ||
-                 (proc_pid_cmdline_is_needed && w->starts_with && w->ends_with && p->cmdline && strstr(p->cmdline, w->compare))))) {
+                 (!w->starts_with && w->ends_with && pclen >= w->comparelen &&
+                  !strcmp(w->compare, &p->comm[pclen - w->comparelen])) ||
+                 (proc_pid_cmdline_is_needed && w->starts_with && w->ends_with && p->cmdline &&
+                  strstr(p->cmdline, w->compare))))) {
             if (w->target)
                 p->target = w->target;
             else
@@ -561,7 +565,10 @@ static inline int read_proc_pid_stat(ebpf_pid_data_t *p)
     if (unlikely(debug_enabled || (p->target && p->target->debug_enabled)))
         debug_log_int(
             "READ PROC/PID/STAT: %s/proc/%d/stat, process: '%s' on target '%s'",
-            netdata_configured_host_prefix, p->pid, p->comm, (p->target) ? p->target->name : "UNSET");
+            netdata_configured_host_prefix,
+            p->pid,
+            p->comm,
+            (p->target) ? p->target->name : "UNSET");
 
 without_cmdline_target:
     p->has_proc_file = 1;
@@ -587,11 +594,11 @@ static inline int ebpf_collect_data_for_pid(pid_t pid)
         return 0;
     }
 
-    ebpf_pid_data_t *p = ebpf_get_pid_data((uint32_t)pid, 0, NULL, EBPF_PIDS_PROC_FILE);
+    ebpf_pid_data_t *p = ebpf_get_pid_data((uint32_t)pid, 0, NULL, NETDATA_EBPF_PIDS_PROC_FILE);
     read_proc_pid_stat(p);
 
     // check its parent pid
-    if (unlikely( p->ppid > (uint32_t)pid_max)) {
+    if (unlikely(p->ppid > (uint32_t)pid_max)) {
         netdata_log_error("Pid %d (command '%s') states invalid parent pid %u. Using 0.", pid, p->comm, p->ppid);
         p->ppid = 0;
     }
@@ -618,7 +625,7 @@ static inline void link_all_processes_to_their_parents(void)
             continue;
         }
 
-//        pp = &ebpf_pids[p->ppid];
+        //        pp = &ebpf_pids[p->ppid];
         pp = ebpf_find_pid_data(p->ppid);
         if (likely(pp && pp->pid)) {
             p->parent = pp;
@@ -626,8 +633,12 @@ static inline void link_all_processes_to_their_parents(void)
 
             if (unlikely(debug_enabled || (p->target && p->target->debug_enabled)))
                 debug_log_int(
-                    "child %d (%s) on target '%s' has parent %d (%s).", p->pid, p->comm,
-                    (p->target) ? p->target->name : "UNSET", pp->pid, pp->comm);
+                    "child %d (%s) on target '%s' has parent %d (%s).",
+                    p->pid,
+                    p->comm,
+                    (p->target) ? p->target->name : "UNSET",
+                    pp->pid,
+                    pp->comm);
         } else {
             p->parent = NULL;
             debug_log("pid %d %s states parent %d, but the later does not exist.", p->pid, p->comm, p->ppid);
@@ -660,8 +671,12 @@ static void apply_apps_groups_targets_inheritance(void)
 
                 if (debug_enabled || (p->target && p->target->debug_enabled))
                     debug_log_int(
-                        "TARGET INHERITANCE: %s is inherited by %u (%s) from its parent %d (%s).", p->target->name,
-                        p->pid, p->comm, p->parent->pid, p->parent->comm);
+                        "TARGET INHERITANCE: %s is inherited by %u (%s) from its parent %d (%s).",
+                        p->target->name,
+                        p->pid,
+                        p->comm,
+                        p->parent->pid,
+                        p->parent->comm);
             }
         }
     }
@@ -699,8 +714,12 @@ static void apply_apps_groups_targets_inheritance(void)
 
                     if (debug_enabled || (p->target && p->target->debug_enabled))
                         debug_log_int(
-                            "TARGET INHERITANCE: %s is inherited by %d (%s) from its child %d (%s).", p->target->name,
-                            p->parent->pid, p->parent->comm, p->pid, p->comm);
+                            "TARGET INHERITANCE: %s is inherited by %d (%s) from its child %d (%s).",
+                            p->target->name,
+                            p->parent->pid,
+                            p->parent->comm,
+                            p->pid,
+                            p->comm);
                 }
 
                 found++;
@@ -713,7 +732,7 @@ static void apply_apps_groups_targets_inheritance(void)
     // init goes always to default target
     ebpf_pid_data_t *pid_entry = ebpf_find_or_create_pid_data(INIT_PID);
     pid_entry->target = apps_groups_default_target;
-//    ebpf_pids[INIT_PID].target = apps_groups_default_target;
+    //    ebpf_pids[INIT_PID].target = apps_groups_default_target;
 
     // pid 0 goes always to default target
     pid_entry = ebpf_find_or_create_pid_data(0);
@@ -752,7 +771,11 @@ static void apply_apps_groups_targets_inheritance(void)
                 if (debug_enabled || (p->target && p->target->debug_enabled))
                     debug_log_int(
                         "TARGET INHERITANCE: %s is inherited by %d (%s) from its parent %d (%s) at phase 2.",
-                        p->target->name, p->pid, p->comm, p->parent->pid, p->parent->comm);
+                        p->target->name,
+                        p->pid,
+                        p->comm,
+                        p->parent->pid,
+                        p->parent->comm);
             }
         }
     }
@@ -786,7 +809,6 @@ static inline void post_aggregate_targets(struct ebpf_target *root)
  */
 void ebpf_del_pid_entry(pid_t pid)
 {
-
     //ebpf_pid_data_t *p = &ebpf_pids[pid];
     ebpf_pid_data_t *p = ebpf_find_pid_data(pid);
 
@@ -800,7 +822,7 @@ void ebpf_del_pid_entry(pid_t pid)
     if (p->prev)
         p->prev->next = p->next;
 
-    if ((p->thread_collecting & EBPF_PIDS_PROC_FILE) || p->has_proc_file)
+    if ((p->thread_collecting & NETDATA_EBPF_PIDS_PROC_FILE) || p->has_proc_file)
         ebpf_all_pids_count--;
 
     rw_spinlock_write_lock(&ebpf_judy_pid.index.rw_spinlock);
@@ -810,7 +832,8 @@ void ebpf_del_pid_entry(pid_t pid)
             Word_t local_socket = 0;
             Pvoid_t *socket_value;
             bool first_socket = true;
-            while ((socket_value = JudyLFirstThenNext(pid_ptr->socket_stats.JudyLArray, &local_socket, &first_socket))) {
+            while (
+                (socket_value = JudyLFirstThenNext(pid_ptr->socket_stats.JudyLArray, &local_socket, &first_socket))) {
                 netdata_socket_plus_t *socket_clean = *socket_value;
                 aral_freez(aral_socket_table, socket_clean);
             }
@@ -902,125 +925,6 @@ static inline void aggregate_pid_on_target(struct ebpf_target *w, ebpf_pid_data_
     w->root_pid = pid_on_target;
 }
 
-/**
- * Process Accumulator
- *
- * Sum all values read from kernel and store in the first address.
- *
- * @param out the vector with read values.
- * @param maps_per_core do I need to read all cores?
- */
-void ebpf_process_apps_accumulator(ebpf_process_stat_t *out, int maps_per_core)
-{
-    int i, end = (maps_per_core) ? ebpf_nprocs : 1;
-    ebpf_process_stat_t *total = &out[0];
-    uint64_t ct = total->ct;
-    for (i = 1; i < end; i++) {
-        ebpf_process_stat_t *w = &out[i];
-        total->exit_call += w->exit_call;
-        total->task_err += w->task_err;
-        total->create_thread += w->create_thread;
-        total->create_process += w->create_process;
-        total->release_call += w->release_call;
-
-        if (w->ct > ct)
-            ct = w->ct;
-    }
-    total->ct = ct;
-}
-
-/**
- * Sum values for pid
- *
- * @param structure to store result.
- * @param root the structure with all available PIDs
- */
-void ebpf_process_sum_values_for_pids(ebpf_process_stat_t *process, struct ebpf_pid_on_target *root)
-{
-    memset(process, 0, sizeof(ebpf_process_stat_t));
-    for (; root; root = root->next) {
-        int32_t pid = root->pid;
-        ebpf_pid_data_t *local_pid = ebpf_get_pid_data(pid, 0, NULL, EBPF_PIDS_PROCESS_IDX);
-        ebpf_publish_process_t *in = local_pid->process;
-        if (!in)
-            continue;
-
-        process->task_err += in->task_err;
-        process->release_call += in->release_call;
-        process->exit_call += in->exit_call;
-        process->create_thread += in->create_thread;
-        process->create_process += in->create_process;
-    }
-}
-
-/**
- * Collect data for all process
- *
- * Read data from hash table and store it in appropriate vectors.
- * It also creates the link between targets and PIDs.
- *
- * @param tbl_pid_stats_fd      The mapped file descriptor for the hash table.
- * @param maps_per_core         do I have hash maps per core?
- */
-void collect_data_for_all_processes(int tbl_pid_stats_fd, int maps_per_core)
-{
-    if (tbl_pid_stats_fd == -1)
-        return;
-
-    pids_fd[EBPF_PIDS_PROCESS_IDX] = tbl_pid_stats_fd;
-    size_t length =  sizeof(ebpf_process_stat_t);
-    if (maps_per_core)
-        length *= ebpf_nprocs;
-
-    if (tbl_pid_stats_fd != -1) {
-
-        uint32_t key = 0, next_key = 0;
-        while (bpf_map_get_next_key(tbl_pid_stats_fd, &key, &next_key) == 0) {
-            if (bpf_map_lookup_elem(tbl_pid_stats_fd, &key, process_stat_vector)) {
-                goto end_process_loop;
-            }
-
-            ebpf_process_apps_accumulator(process_stat_vector, maps_per_core);
-
-            ebpf_pid_data_t *local_pid = ebpf_get_pid_data(key, 0, NULL, EBPF_PIDS_PROCESS_IDX);
-            ebpf_publish_process_t *w = local_pid->process;
-            if (!w)
-                local_pid->process = w = ebpf_process_allocate_publish();
-
-            if (!w->ct || w->ct != process_stat_vector[0].ct) {
-                w->ct = process_stat_vector[0].ct;
-                w->create_thread = process_stat_vector[0].create_thread;
-                w->exit_call = process_stat_vector[0].exit_call;
-                w->create_thread = process_stat_vector[0].create_thread;
-                w->create_process = process_stat_vector[0].create_process;
-                w->release_call = process_stat_vector[0].release_call;
-                w->task_err = process_stat_vector[0].task_err;
-            } else {
-                if (kill(key, 0)) { // No PID found
-                    ebpf_reset_specific_pid_data(local_pid);
-                } else { // There is PID, but there is not data anymore
-                    ebpf_release_pid_data(local_pid, tbl_pid_stats_fd, key, EBPF_PIDS_PROCESS_IDX);
-                    ebpf_process_release_publish(w);
-                    local_pid->process = NULL;
-                }
-            }
-
-end_process_loop:
-            memset(process_stat_vector, 0, length);
-            key = next_key;
-        }
-    }
-
-    struct ebpf_target *w;
-    for (w = apps_groups_root_target; w; w = w->next) {
-        if (unlikely(!(w->processes)))
-            continue;
-
-        ebpf_process_sum_values_for_pids(&w->process, w->root_pid);
-    }
-
-}
-
 /**
  *
  */
