@@ -5,7 +5,8 @@
 
 // Module name & description
 #define NETDATA_EBPF_MODULE_NAME_SHM "shm"
-#define NETDATA_EBPF_SHM_MODULE_DESC "Show calls to syscalls shmget(2), shmat(2), shmdt(2) and shmctl(2). This thread is integrated with apps and cgroup."
+#define NETDATA_EBPF_SHM_MODULE_DESC                                                                                   \
+    "Show calls to syscalls shmget(2), shmat(2), shmdt(2) and shmctl(2). This thread is integrated with apps and cgroup."
 
 // charts
 #define NETDATA_SHM_GLOBAL_CHART "shared_memory_calls"
@@ -28,33 +29,7 @@
 #define NETDATA_SYSTEMD_SHM_DT_CONTEXT "systemd.service.shmdt"
 #define NETDATA_SYSTEMD_SHM_CTL_CONTEXT "systemd.service.shmctl"
 
-typedef struct __attribute__((packed)) netdata_publish_shm {
-    uint64_t ct;
-
-    uint32_t get;
-    uint32_t at;
-    uint32_t dt;
-    uint32_t ctl;
-} netdata_publish_shm_t;
-
-typedef struct netdata_ebpf_shm {
-    uint64_t ct;
-    uint32_t tgid;
-    uint32_t uid;
-    uint32_t gid;
-    char name[TASK_COMM_LEN];
-
-    uint32_t get;
-    uint32_t at;
-    uint32_t dt;
-    uint32_t ctl;
-} netdata_ebpf_shm_t;
-
-enum shm_tables {
-    NETDATA_PID_SHM_TABLE,
-    NETDATA_SHM_CONTROLLER,
-    NETDATA_SHM_GLOBAL_TABLE
-};
+enum shm_tables { NETDATA_PID_SHM_TABLE, NETDATA_SHM_CONTROLLER, NETDATA_SHM_GLOBAL_TABLE };
 
 enum shm_counters {
     NETDATA_KEY_SHMGET_CALL,
