@@ -85,18 +85,22 @@ struct physical_disk system_physical_total = {
     .collected_metadata = true,
 };
 
-static void dict_logical_disk_insert_cb(const DICTIONARY_ITEM *item __maybe_unused, void *value, void *data __maybe_unused) {
+static void
+dict_logical_disk_insert_cb(const DICTIONARY_ITEM *item __maybe_unused, void *value, void *data __maybe_unused)
+{
     struct logical_disk *d = value;
 
     d->percentDiskFree.key = "% Free Space";
     // d->freeMegabytes.key = "Free Megabytes";
 }
 
-static void logical_disk_cleanup(struct logical_disk *d) {
+static void logical_disk_cleanup(struct logical_disk *d)
+{
     rrdset_is_obsolete___safe_from_collector_thread(d->st_disk_space);
 }
 
-static void physical_disk_initialize(struct physical_disk *d) {
+static void physical_disk_initialize(struct physical_disk *d)
+{
     d->percentIdleTime.key = "% Idle Time";
     d->percentDiskTime.key = "% Disk Time";
     d->percentDiskReadTime.key = "% Disk Read Time";
@@ -120,7 +124,8 @@ static void physical_disk_initialize(struct physical_disk *d) {
     d->splitIoPerSec.key = "Split IO/Sec";
 }
 
-static void physical_disk_cleanup(struct physical_disk *d) {
+static void physical_disk_cleanup(struct physical_disk *d)
+{
     string_freez(d->device);
     string_freez(d->mount_point);
     string_freez(d->manufacturer);
@@ -141,31 +146,35 @@ static void physical_disk_cleanup(struct physical_disk *d) {
     rrdset_is_obsolete___safe_from_collector_thread(d->st_split);
 }
 
-void dict_physical_disk_insert_cb(const DICTIONARY_ITEM *item __maybe_unused, void *value, void *data __maybe_unused) {
+void dict_physical_disk_insert_cb(const DICTIONARY_ITEM *item __maybe_unused, void *value, void *data __maybe_unused)
+{
     struct physical_disk *pd = value;
     physical_disk_initialize(pd);
 }
 
 static DICTIONARY *logicalDisks = NULL, *physicalDisks = NULL;
-static void initialize(void) {
+static void initialize(void)
+{
     physical_disk_initialize(&system_physical_total);
 
-    logicalDisks = dictionary_create_advanced(DICT_OPTION_DONT_OVERWRITE_VALUE |
-                                                  DICT_OPTION_FIXED_SIZE, NULL, sizeof(struct logical_disk));
+    logicalDisks = dictionary_create_advanced(
+        DICT_OPTION_DONT_OVERWRITE_VALUE | DICT_OPTION_FIXED_SIZE, NULL, sizeof(struct logical_disk));
 
     dictionary_register_insert_callback(logicalDisks, dict_logical_disk_insert_cb, NULL);
 
-    physicalDisks = dictionary_create_advanced(DICT_OPTION_DONT_OVERWRITE_VALUE |
-                                                  DICT_OPTION_FIXED_SIZE, NULL, sizeof(struct physical_disk));
+    physicalDisks = dictionary_create_advanced(
+        DICT_OPTION_DONT_OVERWRITE_VALUE | DICT_OPTION_FIXED_SIZE, NULL, sizeof(struct physical_disk));
 
     dictionary_register_insert_callback(physicalDisks, dict_physical_disk_insert_cb, NULL);
 }
 
-static STRING *getFileSystemType(struct logical_disk *d, const char* diskName) {
-    if (!diskName || !*diskName) return NULL;
+static STRING *getFileSystemType(struct logical_disk *d, const char *diskName)
+{
+    if (!diskName || !*diskName)
+        return NULL;
 
-    char fileSystemNameBuffer[128] = {0};  // Buffer for file system name
-    char pathBuffer[256] = {0};            // Path buffer to accommodate different formats
+    char fileSystemNameBuffer[128] = {0}; // Buffer for file system name
+    char pathBuffer[256] = {0};           // Path buffer to accommodate different formats
     DWORD serialNumber = 0;
     DWORD maxComponentLength = 0;
     DWORD fileSystemFlags = 0;
@@ -173,75 +182,86 @@ static STRING *getFileSystemType(struct logical_disk *d, const char* diskName) {
 
     // Check if the input is likely a drive letter (e.g., "C:")
     if (isalpha((uint8_t)diskName[0]) && diskName[1] == ':' && diskName[2] == '\0')
-        snprintf(pathBuffer, sizeof(pathBuffer), "%s\\", diskName);  // Format as "C:\"
+        snprintf(pathBuffer, sizeof(pathBuffer), "%s\\", diskName); // Format as "C:\"
     else
         // Assume it's a Volume GUID path or a device path
-        snprintf(pathBuffer, sizeof(pathBuffer), "\\\\.\\%s\\", diskName);  // Format as "\\.\HarddiskVolume1\"
+        snprintf(pathBuffer, sizeof(pathBuffer), "\\\\.\\%s\\", diskName); // Format as "\\.\HarddiskVolume1\"
 
     d->DriveType = GetDriveTypeA(pathBuffer);
 
     // Attempt to get the volume information
     success = GetVolumeInformationA(
-        pathBuffer,                // Path to the disk
-        NULL,                      // We don't need the volume name
-        0,                         // Size of volume name buffer is 0
-        &serialNumber,             // Volume serial number
-        &maxComponentLength,       // Maximum component length
-        &fileSystemFlags,          // File system flags
-        fileSystemNameBuffer,      // File system name buffer
+        pathBuffer,                  // Path to the disk
+        NULL,                        // We don't need the volume name
+        0,                           // Size of volume name buffer is 0
+        &serialNumber,               // Volume serial number
+        &maxComponentLength,         // Maximum component length
+        &fileSystemFlags,            // File system flags
+        fileSystemNameBuffer,        // File system name buffer
         sizeof(fileSystemNameBuffer) // Size of file system name buffer
     );
 
-    if(success) {
+    if (success) {
         d->readonly = fileSystemFlags & FILE_READ_ONLY_VOLUME;
         d->SerialNumber = serialNumber;
 
         if (fileSystemNameBuffer[0]) {
             char *s = fileSystemNameBuffer;
             while (*s) {
-                *s = tolower((uint8_t) *s);
+                *s = tolower((uint8_t)*s);
                 s++;
             }
-            return string_strdupz(fileSystemNameBuffer);  // Duplicate the file system name
+            return string_strdupz(fileSystemNameBuffer); // Duplicate the file system name
         }
     }
     return NULL;
 }
 
-static const char *drive_type_to_str(UINT type) {
-    switch(type) {
+static const char *drive_type_to_str(UINT type)
+{
+    switch (type) {
         default:
-        case 0: return "unknown";
-        case 1: return "norootdir";
-        case 2: return "removable";
-        case 3: return "fixed";
-        case 4: return "remote";
-        case 5: return "cdrom";
-        case 6: return "ramdisk";
+        case 0:
+            return "unknown";
+        case 1:
+            return "norootdir";
+        case 2:
+            return "removable";
+        case 3:
+            return "fixed";
+        case 4:
+            return "remote";
+        case 5:
+            return "cdrom";
+        case 6:
+            return "ramdisk";
     }
 }
 
-static bool do_logical_disk(PERF_DATA_BLOCK *pDataBlock, int update_every, usec_t now_ut) {
+static bool do_logical_disk(PERF_DATA_BLOCK *pDataBlock, int update_every, usec_t now_ut)
+{
     DICTIONARY *dict = logicalDisks;
 
     PERF_OBJECT_TYPE *pObjectType = perflibFindObjectTypeByName(pDataBlock, "LogicalDisk");
-    if(!pObjectType) return false;
+    if (!pObjectType)
+        return false;
 
     PERF_INSTANCE_DEFINITION *pi = NULL;
-    for(LONG i = 0; i < pObjectType->NumInstances ; i++) {
+    for (LONG i = 0; i < pObjectType->NumInstances; i++) {
         pi = perflibForEachInstance(pDataBlock, pObjectType, pi);
-        if(!pi) break;
+        if (!pi)
+            break;
 
-        if(!getInstanceName(pDataBlock, pObjectType, pi, windows_shared_buffer, sizeof(windows_shared_buffer)))
+        if (!getInstanceName(pDataBlock, pObjectType, pi, windows_shared_buffer, sizeof(windows_shared_buffer)))
             strncpyz(windows_shared_buffer, "[unknown]", sizeof(windows_shared_buffer) - 1);
 
-        if(strcasecmp(windows_shared_buffer, "_Total") == 0)
+        if (strcasecmp(windows_shared_buffer, "_Total") == 0)
             continue;
 
         struct logical_disk *d = dictionary_set(dict, windows_shared_buffer, NULL, sizeof(*d));
         d->last_collected = now_ut;
 
-        if(!d->collected_metadata) {
+        if (!d->collected_metadata) {
             d->filesystem = getFileSystemType(d, windows_shared_buffer);
             d->collected_metadata = true;
         }
@@ -249,25 +269,29 @@ static bool do_logical_disk(PERF_DATA_BLOCK *pDataBlock, int update_every, usec_
         perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->percentDiskFree);
         // perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->freeMegabytes);
 
-        if(!d->st_disk_space) {
+        if (!d->st_disk_space) {
             d->st_disk_space = rrdset_create_localhost(
-                "disk_space"
-                , windows_shared_buffer
-                , NULL
-                , windows_shared_buffer
-                , "disk.space"
-                , "Disk Space Usage"
-                , "GiB"
-                , PLUGIN_WINDOWS_NAME
-                , "PerflibStorage"
-                , NETDATA_CHART_PRIO_DISKSPACE_SPACE
-                , update_every
-                , RRDSET_TYPE_STACKED
-            );
+                "disk_space",
+                windows_shared_buffer,
+                NULL,
+                windows_shared_buffer,
+                "disk.space",
+                "Disk Space Usage",
+                "GiB",
+                PLUGIN_WINDOWS_NAME,
+                "PerflibStorage",
+                NETDATA_CHART_PRIO_DISKSPACE_SPACE,
+                update_every,
+                RRDSET_TYPE_STACKED);
 
             rrdlabels_add(d->st_disk_space->rrdlabels, "mount_point", windows_shared_buffer, RRDLABEL_SRC_AUTO);
-            rrdlabels_add(d->st_disk_space->rrdlabels, "drive_type", drive_type_to_str(d->DriveType), RRDLABEL_SRC_AUTO);
-            rrdlabels_add(d->st_disk_space->rrdlabels, "filesystem", d->filesystem ? string2str(d->filesystem) : "unknown", RRDLABEL_SRC_AUTO);
+            rrdlabels_add(
+                d->st_disk_space->rrdlabels, "drive_type", drive_type_to_str(d->DriveType), RRDLABEL_SRC_AUTO);
+            rrdlabels_add(
+                d->st_disk_space->rrdlabels,
+                "filesystem",
+                d->filesystem ? string2str(d->filesystem) : "unknown",
+                RRDLABEL_SRC_AUTO);
             rrdlabels_add(d->st_disk_space->rrdlabels, "rw_mode", d->readonly ? "ro" : "rw", RRDLABEL_SRC_AUTO);
 
             {
@@ -281,16 +305,21 @@ static bool do_logical_disk(PERF_DATA_BLOCK *pDataBlock, int update_every, usec_
         }
 
         // percentDiskFree has the free space in Data and the size of the disk in Time, in MiB.
-        rrddim_set_by_pointer(d->st_disk_space, d->rd_disk_space_free, (collected_number)d->percentDiskFree.current.Data);
-        rrddim_set_by_pointer(d->st_disk_space, d->rd_disk_space_used, (collected_number)(d->percentDiskFree.current.Time - d->percentDiskFree.current.Data));
+        rrddim_set_by_pointer(
+            d->st_disk_space, d->rd_disk_space_free, (collected_number)d->percentDiskFree.current.Data);
+        rrddim_set_by_pointer(
+            d->st_disk_space,
+            d->rd_disk_space_used,
+            (collected_number)(d->percentDiskFree.current.Time - d->percentDiskFree.current.Data));
         rrdset_done(d->st_disk_space);
     }
 
     // cleanup
     {
         struct logical_disk *d;
-        dfe_start_write(dict, d) {
-            if(d->last_collected < now_ut) {
+        dfe_start_write(dict, d)
+        {
+            if (d->last_collected < now_ut) {
                 logical_disk_cleanup(d);
                 dictionary_del(dict, d_dfe.name);
             }
@@ -302,38 +331,44 @@ static bool do_logical_disk(PERF_DATA_BLOCK *pDataBlock, int update_every, usec_
     return true;
 }
 
-static void physical_disk_labels(RRDSET *st, void *data) {
+static void physical_disk_labels(RRDSET *st, void *data)
+{
     struct physical_disk *d = data;
 
-    if(d->device)
+    if (d->device)
         rrdlabels_add(st->rrdlabels, "device", string2str(d->device), RRDLABEL_SRC_AUTO);
 
     if (d->mount_point)
         rrdlabels_add(st->rrdlabels, "mount_point", string2str(d->mount_point), RRDLABEL_SRC_AUTO);
 
-//    if (d->manufacturer)
-//        rrdlabels_add(st->rrdlabels, "manufacturer", string2str(d->manufacturer), RRDLABEL_SRC_AUTO);
+    //    if (d->manufacturer)
+    //        rrdlabels_add(st->rrdlabels, "manufacturer", string2str(d->manufacturer), RRDLABEL_SRC_AUTO);
 
     if (d->model)
         rrdlabels_add(st->rrdlabels, "model", string2str(d->model), RRDLABEL_SRC_AUTO);
 
-//    if (d->media_type)
-//        rrdlabels_add(st->rrdlabels, "media_type", string2str(d->media_type), RRDLABEL_SRC_AUTO);
+    //    if (d->media_type)
+    //        rrdlabels_add(st->rrdlabels, "media_type", string2str(d->media_type), RRDLABEL_SRC_AUTO);
 
-//    if (d->name)
-//        rrdlabels_add(st->rrdlabels, "name", string2str(d->name), RRDLABEL_SRC_AUTO);
+    //    if (d->name)
+    //        rrdlabels_add(st->rrdlabels, "name", string2str(d->name), RRDLABEL_SRC_AUTO);
 
     if (d->device_id)
         rrdlabels_add(st->rrdlabels, "device_id", string2str(d->device_id), RRDLABEL_SRC_AUTO);
 }
 
-static bool str_is_numeric(const char *s) {
-    while(*s) if(!isdigit((uint8_t)*s++)) return false;
+static bool str_is_numeric(const char *s)
+{
+    while (*s)
+        if (!isdigit((uint8_t)*s++))
+            return false;
     return true;
 }
 
-static inline double perflib_average_timer_ms(COUNTER_DATA *d) {
-    if(!d->updated) return 0.0;
+static inline double perflib_average_timer_ms(COUNTER_DATA *d)
+{
+    if (!d->updated)
+        return 0.0;
 
     ULONGLONG data1 = d->current.Data;
     ULONGLONG data0 = d->previous.Data;
@@ -341,35 +376,39 @@ static inline double perflib_average_timer_ms(COUNTER_DATA *d) {
     LONGLONG time0 = d->previous.Time;
     LONGLONG freq1 = d->current.Frequency;
 
-    if(data1 >= data0 && time1 > time0 && time0 && freq1)
+    if (data1 >= data0 && time1 > time0 && time0 && freq1)
         return ((double)(data1 - data0) / (double)(freq1 / MSEC_PER_SEC)) / (double)(time1 - time0);
 
     return 0;
 }
 
-static inline uint64_t perflib_average_bulk(COUNTER_DATA *d) {
-    if(!d->updated) return 0;
+static inline uint64_t perflib_average_bulk(COUNTER_DATA *d)
+{
+    if (!d->updated)
+        return 0;
 
     ULONGLONG data1 = d->current.Data;
     ULONGLONG data0 = d->previous.Data;
     LONGLONG time1 = d->current.Time;
     LONGLONG time0 = d->previous.Time;
 
-    if(data1 >= data0 && time1 > time0 && time0)
+    if (data1 >= data0 && time1 > time0 && time0)
         return (data1 - data0) / (time1 - time0);
 
     return 0;
 }
 
-static inline uint64_t perflib_idle_time_percent(COUNTER_DATA *d) {
-    if(!d->updated) return 0.0;
+static inline uint64_t perflib_idle_time_percent(COUNTER_DATA *d)
+{
+    if (!d->updated)
+        return 0.0;
 
     ULONGLONG data1 = d->current.Data;
     ULONGLONG data0 = d->previous.Data;
     LONGLONG time1 = d->current.Time;
     LONGLONG time0 = d->previous.Time;
 
-    if(data1 >= data0 && time1 > time0 && time0) {
+    if (data1 >= data0 && time1 > time0 && time0) {
         uint64_t pcent = 100 * (data1 - data0) / (time1 - time0);
         return pcent > 100 ? 100 : pcent;
     }
@@ -380,11 +419,13 @@ static inline uint64_t perflib_idle_time_percent(COUNTER_DATA *d) {
 #define MAX_WMI_DRIVES 100
 static DiskDriveInfoWMI infos[MAX_WMI_DRIVES];
 
-static bool do_physical_disk(PERF_DATA_BLOCK *pDataBlock, int update_every, usec_t now_ut) {
+static bool do_physical_disk(PERF_DATA_BLOCK *pDataBlock, int update_every, usec_t now_ut)
+{
     DICTIONARY *dict = physicalDisks;
 
     PERF_OBJECT_TYPE *pObjectType = perflibFindObjectTypeByName(pDataBlock, "PhysicalDisk");
-    if(!pObjectType) return false;
+    if (!pObjectType)
+        return false;
 
     PERF_INSTANCE_DEFINITION *pi = NULL;
     for (LONG i = 0; i < pObjectType->NumInstances; i++) {
@@ -397,22 +438,22 @@ static bool do_physical_disk(PERF_DATA_BLOCK *pDataBlock, int update_every, usec
 
         int device_index = -1;
         char *device = windows_shared_buffer;
-        char mount_point[128]; mount_point[0] = '\0';
+        char mount_point[128];
+        mount_point[0] = '\0';
 
         struct physical_disk *d;
         bool is_system;
         if (strcasecmp(windows_shared_buffer, "_Total") == 0) {
             d = &system_physical_total;
             is_system = true;
-        }
-        else {
+        } else {
             char *space;
-            if((space = strchr(windows_shared_buffer, ' '))) {
+            if ((space = strchr(windows_shared_buffer, ' '))) {
                 *space++ = '\0';
                 strncpyz(mount_point, space, sizeof(mount_point) - 1);
             }
 
-            if(str_is_numeric(windows_shared_buffer)) {
+            if (str_is_numeric(windows_shared_buffer)) {
                 device_index = str2ull(device, NULL);
                 snprintfz(windows_shared_buffer, sizeof(windows_shared_buffer), "Disk %d", device_index);
                 device = windows_shared_buffer;
@@ -424,10 +465,10 @@ static bool do_physical_disk(PERF_DATA_BLOCK *pDataBlock, int update_every, usec
         d->last_collected = now_ut;
 
         if (!d->collected_metadata) {
-            if(!is_system && device_index != -1) {
+            if (!is_system && device_index != -1) {
                 size_t infoCount = GetDiskDriveInfo(infos, _countof(infos));
-                for(size_t k = 0; k < infoCount ; k++) {
-                    if(infos[k].Index != device_index)
+                for (size_t k = 0; k < infoCount; k++) {
+                    if (infos[k].Index != device_index)
                         continue;
 
                     d->manufacturer = string_strdupz(infos[k].Manufacturer);
@@ -447,11 +488,9 @@ static bool do_physical_disk(PERF_DATA_BLOCK *pDataBlock, int update_every, usec
 
         if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->diskReadBytesPerSec) &&
             perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->diskWriteBytesPerSec)) {
-            if(is_system)
+            if (is_system)
                 common_system_io(
-                        d->diskReadBytesPerSec.current.Data,
-                        d->diskWriteBytesPerSec.current.Data,
-                        update_every);
+                    d->diskReadBytesPerSec.current.Data, d->diskWriteBytesPerSec.current.Data, update_every);
             else
                 common_disk_io(
                     &d->disk_io,
@@ -464,124 +503,120 @@ static bool do_physical_disk(PERF_DATA_BLOCK *pDataBlock, int update_every, usec
                     d);
         }
 
-        if(is_system) continue;
+        if (is_system)
+            continue;
 
         if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->diskReadsPerSec) &&
             perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->diskWritesPerSec)) {
-
             common_disk_ops(
-                    &d->disk_ops,
-                    device,
-                    NULL,
-                    d->diskReadsPerSec.current.Data,
-                    d->diskWritesPerSec.current.Data,
-                    update_every,
-                    physical_disk_labels,
-                    d);
+                &d->disk_ops,
+                device,
+                NULL,
+                d->diskReadsPerSec.current.Data,
+                d->diskWritesPerSec.current.Data,
+                update_every,
+                physical_disk_labels,
+                d);
         }
 
         if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->percentIdleTime)) {
             common_disk_util(
-                    &d->disk_util,
-                    device,
-                    NULL,
-                    100 - perflib_idle_time_percent(&d->percentIdleTime),
-                    update_every,
-                    physical_disk_labels,
-                    d);
+                &d->disk_util,
+                device,
+                NULL,
+                100 - perflib_idle_time_percent(&d->percentIdleTime),
+                update_every,
+                physical_disk_labels,
+                d);
         }
 
         if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->percentDiskTime)) {
             common_disk_busy(
-                    &d->disk_busy,
-                    device,
-                    NULL,
-                    d->percentDiskTime.current.Data / NS100_PER_MS,
-                    update_every,
-                    physical_disk_labels,
-                    d);
+                &d->disk_busy,
+                device,
+                NULL,
+                d->percentDiskTime.current.Data / NS100_PER_MS,
+                update_every,
+                physical_disk_labels,
+                d);
         }
 
         if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->percentDiskReadTime) &&
             perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->percentDiskWriteTime)) {
-
             common_disk_iotime(
-                    &d->disk_iotime,
-                    device,
-                    NULL,
-                    d->percentDiskReadTime.current.Data / NS100_PER_MS,
-                    d->percentDiskWriteTime.current.Data / NS100_PER_MS,
-                    update_every,
-                    physical_disk_labels,
-                    d);
+                &d->disk_iotime,
+                device,
+                NULL,
+                d->percentDiskReadTime.current.Data / NS100_PER_MS,
+                d->percentDiskWriteTime.current.Data / NS100_PER_MS,
+                update_every,
+                physical_disk_labels,
+                d);
         }
 
-        if(perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->currentDiskQueueLength)) {
+        if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->currentDiskQueueLength)) {
             common_disk_qops(
-                    &d->disk_qops,
-                    device,
-                    NULL,
-                    d->currentDiskQueueLength.current.Data,
-                    update_every,
-                    physical_disk_labels,
-                    d);
+                &d->disk_qops,
+                device,
+                NULL,
+                d->currentDiskQueueLength.current.Data,
+                update_every,
+                physical_disk_labels,
+                d);
         }
 
         if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->averageDiskSecondsPerRead) &&
             perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->averageDiskSecondsPerWrite)) {
-
             common_disk_await(
-                    &d->disk_await,
-                    device,
-                    NULL,
-                    perflib_average_timer_ms(&d->averageDiskSecondsPerRead),
-                    perflib_average_timer_ms(&d->averageDiskSecondsPerWrite),
-                    update_every,
-                    physical_disk_labels,
-                    d);
+                &d->disk_await,
+                device,
+                NULL,
+                perflib_average_timer_ms(&d->averageDiskSecondsPerRead),
+                perflib_average_timer_ms(&d->averageDiskSecondsPerWrite),
+                update_every,
+                physical_disk_labels,
+                d);
         }
 
         if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->averageDiskSecondsPerTransfer)) {
             common_disk_svctm(
-                    &d->disk_svctm,
-                    device,
-                    NULL,
-                    perflib_average_timer_ms(&d->averageDiskSecondsPerTransfer),
-                    update_every,
-                    physical_disk_labels,
-                    d);
+                &d->disk_svctm,
+                device,
+                NULL,
+                perflib_average_timer_ms(&d->averageDiskSecondsPerTransfer),
+                update_every,
+                physical_disk_labels,
+                d);
         }
 
         if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->averageDiskBytesPerRead) &&
             perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->averageDiskBytesPerWrite)) {
-
             common_disk_avgsz(
-                    &d->disk_avgsz,
-                    device,
-                    NULL,
-                    perflib_average_bulk(&d->averageDiskBytesPerRead),
-                    perflib_average_bulk(&d->averageDiskBytesPerWrite),
-                    update_every,
-                    physical_disk_labels,
-                    d);
+                &d->disk_avgsz,
+                device,
+                NULL,
+                perflib_average_bulk(&d->averageDiskBytesPerRead),
+                perflib_average_bulk(&d->averageDiskBytesPerWrite),
+                update_every,
+                physical_disk_labels,
+                d);
         }
 
-        if(perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->splitIoPerSec)) {
+        if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &d->splitIoPerSec)) {
             if (!d->st_split) {
                 d->st_split = rrdset_create_localhost(
-                        "disk_split",
-                        device,
-                        NULL,
-                        "iops",
-                        "disk.split",
-                        "Split I/O Operations",
-                        "operations/s",
-                        _COMMON_PLUGIN_NAME,
-                        _COMMON_PLUGIN_MODULE_NAME,
-                        NETDATA_CHART_PRIO_DISK_SPLIT,
-                        update_every,
-                        RRDSET_TYPE_LINE
-                );
+                    "disk_split",
+                    device,
+                    NULL,
+                    "iops",
+                    "disk.split",
+                    "Split I/O Operations",
+                    "operations/s",
+                    _COMMON_PLUGIN_NAME,
+                    _COMMON_PLUGIN_MODULE_NAME,
+                    NETDATA_CHART_PRIO_DISK_SPLIT,
+                    update_every,
+                    RRDSET_TYPE_LINE);
 
                 d->rd_split = rrddim_add(d->st_split, "discards", NULL, 1, 1, RRD_ALGORITHM_INCREMENTAL);
 
@@ -596,8 +631,9 @@ static bool do_physical_disk(PERF_DATA_BLOCK *pDataBlock, int update_every, usec
     // cleanup
     {
         struct physical_disk *d;
-        dfe_start_write(dict, d) {
-            if(d->last_collected < now_ut) {
+        dfe_start_write(dict, d)
+        {
+            if (d->last_collected < now_ut) {
                 physical_disk_cleanup(d);
                 dictionary_del(dict, d_dfe.name);
             }
@@ -609,20 +645,22 @@ static bool do_physical_disk(PERF_DATA_BLOCK *pDataBlock, int update_every, usec
     return true;
 }
 
-int do_PerflibStorage(int update_every, usec_t dt __maybe_unused) {
+int do_PerflibStorage(int update_every, usec_t dt __maybe_unused)
+{
     static bool initialized = false;
 
-    if(unlikely(!initialized)) {
+    if (unlikely(!initialized)) {
         initialize();
         initialized = true;
     }
 
     DWORD id = RegistryFindIDByName("LogicalDisk");
-    if(id == PERFLIB_REGISTRY_NAME_NOT_FOUND)
+    if (id == PERFLIB_REGISTRY_NAME_NOT_FOUND)
         return -1;
 
     PERF_DATA_BLOCK *pDataBlock = perflibGetPerformanceData(id);
-    if(!pDataBlock) return -1;
+    if (!pDataBlock)
+        return -1;
 
     usec_t now_ut = now_monotonic_usec();
     do_logical_disk(pDataBlock, update_every, now_ut);
