@@ -1026,7 +1026,7 @@ int main(int argc, char **argv) {
     for(iteration = 0; 1; iteration++) {
         usec_t dt = heartbeat_next(&hb);
 
-        if(unlikely(netdata_exit)) break;
+        if(unlikely(exit_initiated_get())) break;
 
         if(unlikely(debug && iteration))
             fprintf(stderr, "xenstat.plugin: iteration %zu, dt %lu usec\n", iteration, dt);
