@@ -488,10 +488,10 @@ int become_daemon(int dont_fork, const char *user) {
     if(user && *user) {
         daemon_status_file_startup_step("startup(become daemon - user)");
         if(become_user(user, pidfd) != 0) {
-            netdata_log_error("Cannot become user '%s'. Continuing as we are.", user);
+            netdata_log_error("Cannot switch to user '%s'. Continuing with current privileges.", user);
         }
         else
-            netdata_log_debug(D_SYSTEM, "Successfully became user '%s'.", user);
+            netdata_log_info("Successfully switched to user '%s'.", user);
     }
     else {
         daemon_status_file_startup_step("startup(become daemon - dirs)");
