@@ -46,7 +46,6 @@ ENUM_STR_DEFINE_FUNCTIONS(DAEMON_OS_TYPE, DAEMON_OS_TYPE_UNKNOWN, "unknown");
 
 static DAEMON_STATUS_FILE last_session_status = {
     .v = 0,
-    .spinlock = SPINLOCK_INITIALIZER,
     .fatal = {
         .spinlock = SPINLOCK_INITIALIZER,
     },
@@ -54,7 +53,6 @@ static DAEMON_STATUS_FILE last_session_status = {
 
 static DAEMON_STATUS_FILE session_status = {
     .v = STATUS_FILE_VERSION,
-    .spinlock = SPINLOCK_INITIALIZER,
     .fatal = {
         .spinlock = SPINLOCK_INITIALIZER,
     },
@@ -709,7 +707,7 @@ static void daemon_status_file_migrate_once(void) {
         session_status.reliability++;
     }
 
-    safecpy(session_status.stack_traces, capture_stack_trace_backend());
+    safecpy(session_status.stack_traces, stacktrace_backend());
 
     fill_dmi_info(&session_status);
 
@@ -721,7 +719,6 @@ static void daemon_status_file_refresh(DAEMON_STATUS status) {
     usec_t now_ut = now_realtime_usec();
 
     dsf_acquire(session_status);
-    spinlock_lock(&session_status.spinlock);
 
 #if defined(OS_LINUX)
     session_status.os_type = DAEMON_OS_TYPE_LINUX;
@@ -764,7 +761,12 @@ static void daemon_status_file_refresh(DAEMON_STATUS status) {
         cs == CLOUD_STATUS_INDIRECT)                                // this is a final state
         session_status.cloud_status = cs;
 
+
+#ifdef ENABLE_DBENGINE
     session_status.oom_protection = dbengine_out_of_memory_protection;
+#else
+    session_status.oom_protection = 0;
+#endif
     
     OS_PROCESS_MEMORY proc_mem = os_process_memory(0);
     if(OS_PROCESS_MEMORY_OK(proc_mem))
@@ -834,7 +836,6 @@ static void daemon_status_file_refresh(DAEMON_STATUS status) {
         simple_pattern_free(sqlite_pattern);
     }
 
-    spinlock_unlock(&session_status.spinlock);
     dsf_release(session_status);
 }
 
@@ -1320,7 +1321,7 @@ static void daemon_status_file_save_twice_if_we_can_get_stack_trace(BUFFER *wb,
     // IMPORTANT: NO LOCKS OR ALLOCATIONS HERE, THIS FUNCTION IS CALLED FROM SIGNAL HANDLERS
     // THIS FUNCTION MUST USE ONLY ASYNC-SIGNAL-SAFE OPERATIONS
 
-    if(capture_stack_trace_available())
+    if(stacktrace_available())
         set_stack_trace_message_if_empty(&session_status, STACK_TRACE_INFO_PREFIX "will now attempt to get stack trace - if you see this message, we couldn't get it.");
     else
         set_stack_trace_message_if_empty(&session_status, STACK_TRACE_INFO_PREFIX "no stack trace backend available");
@@ -1332,11 +1333,11 @@ static void daemon_status_file_save_twice_if_we_can_get_stack_trace(BUFFER *wb,
         return;
 
     buffer_flush(wb);
-    
-    capture_stack_trace(wb);
+
+    stacktrace_capture(wb);
 
     // Store the first netdata function from the stack trace if available
-    const char *first_nd_fn = capture_stack_trace_root_cause_function();
+    const char *first_nd_fn = stacktrace_root_cause_function();
     if (first_nd_fn && *first_nd_fn &&
         (!ds->fatal.function[0] || strncmp(ds->fatal.function, "thread:", 7) == 0))
         safecpy(ds->fatal.function, first_nd_fn);
@@ -1487,14 +1488,14 @@ bool daemon_status_file_deadly_signal_received(EXIT_REASON reason, SIGNAL_CODE c
         }
     }
 
-    bool safe_to_get_stack_trace = reason != EXIT_REASON_SIGABRT || capture_stack_trace_is_async_signal_safe();
-    bool get_stack_trace = capture_stack_trace_available() && safe_to_get_stack_trace && stack_trace_is_empty(&session_status);
+    bool safe_to_get_stack_trace = reason != EXIT_REASON_SIGABRT || stacktrace_capture_is_async_signal_safe();
+    bool get_stack_trace = stacktrace_available() && safe_to_get_stack_trace && stack_trace_is_empty(&session_status);
 
     // save it
     if(get_stack_trace)
         daemon_status_file_save_twice_if_we_can_get_stack_trace(static_save_buffer, &session_status, true);
     else {
-        if (!capture_stack_trace_available())
+        if (!stacktrace_available())
             set_stack_trace_message_if_empty(&session_status, STACK_TRACE_INFO_PREFIX "no stack trace backend available");
         else
             set_stack_trace_message_if_empty(&session_status, STACK_TRACE_INFO_PREFIX "not safe to get a stack trace for this signal using this backend");
