@@ -757,5 +757,8 @@ static inline bool query_target_has_percentage_units(QUERY_TARGET *qt) {
     return query_target_has_percentage_of_group(qt);
 }
 
+uint32_t rrdcontext_queue_version(RRDCONTEXT_QUEUE_JudyLSet *queue);
+int32_t rrdcontext_queue_entries(RRDCONTEXT_QUEUE_JudyLSet *queue);
+
 #endif // NETDATA_RRDCONTEXT_H
 
