@@ -6,11 +6,6 @@
 #include "libnetdata/libnetdata.h"
 #include "rrdlabels.h"
 
-struct pattern_array_item {
-    Word_t size;
-    Pvoid_t JudyL;
-};
-
 struct pattern_array {
     Word_t key_count;
     Pvoid_t JudyL;
