@@ -17,7 +17,7 @@ typedef bool (*rrd_function_is_cancelled_cb_t)(void *is_cancelled_cb_data);
 typedef void (*rrd_function_cancel_cb_t)(void *data);
 typedef void (*rrd_function_register_canceller_cb_t)(void *register_cancel_cb_data, rrd_function_cancel_cb_t cancel_cb, void *cancel_cb_data);
 typedef void (*rrd_function_progress_cb_t)(void *data, size_t done, size_t all);
-typedef void (*rrd_function_progresser_cb_t)(void *data);
+typedef void (*rrd_function_progresser_cb_t)(const char *transaction, void *data);
 typedef void (*rrd_function_register_progresser_cb_t)(void *register_progresser_cb_data, rrd_function_progresser_cb_t progresser_cb, void *progresser_cb_data);
 
 struct rrd_function_execute {
