@@ -2,7 +2,11 @@
 #ifndef NETDATA_SQLITE_DB_MIGRATION_H
 #define NETDATA_SQLITE_DB_MIGRATION_H
 
-#include "daemon/common.h"
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+#include "database/rrd.h"
 #include "database/sqlite/vendored/sqlite3.h"
 
 int perform_database_migration(sqlite3 *database, int target_version);
@@ -10,4 +14,8 @@ int perform_context_database_migration(sqlite3 *database, int target_version);
 int table_exists_in_database(sqlite3 *database, const char *table);
 int perform_ml_database_migration(sqlite3 *database, int target_version);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif //NETDATA_SQLITE_DB_MIGRATION_H
