@@ -8,6 +8,7 @@ import (
 	"errors"
 	"fmt"
 	"log/slog"
+	"slices"
 	"strconv"
 	"strings"
 	"time"
@@ -737,6 +738,10 @@ func userConfigFromPayload(cfg any, jobName string, fn functions.Function) ([]by
 		return nil, err
 	}
 
+	yms = slices.DeleteFunc(yms, func(item yaml.MapItem) bool {
+		return item.Key == "name"
+	})
+
 	yms = append([]yaml.MapItem{{Key: "name", Value: jobName}}, yms...)
 
 	v := map[string]any{
