@@ -61,6 +61,17 @@ const (
 	prioDeploymentAge
 )
 
+const (
+	prioCronJobJobsCountByStatus = 50700 + iota
+	prioCronJobJobsFailedByReason
+	prioCronJobLastExecutionStatus
+	prioCronJobLastCompletionDuration
+	prioCronJobLastCompletedTimeAgo
+	prioCronJobLastScheduleTimeAgo
+	prioCronJobSuspendStatus
+	prioCronJobAge
+)
+
 const (
 	labelKeyPrefix = "k8s_"
 	//labelKeyLabelPrefix      = labelKeyPrefix + "label_"
@@ -78,6 +89,7 @@ const (
 	labelKeyContainerID    = labelKeyPrefix + "container_id"
 	labelKeyQoSClass       = labelKeyPrefix + "qos_class"
 	labelKeyDeploymentName = labelKeyPrefix + "deployment_name"
+	labelKeyCronJobName    = labelKeyPrefix + "cronjob_name"
 )
 
 var baseCharts = module.Charts{
@@ -135,6 +147,17 @@ var deploymentChartsTmpl = module.Charts{
 	deploymentAgeChartTmpl.Copy(),
 }
 
+var cronJobChartsTmpl = module.Charts{
+	cronJobJobsCountByStatusChartTmpl.Copy(),
+	cronJobJobsFailedByReasonChartTmpl.Copy(),
+	cronJobLastExecutionStatusChartTmpl.Copy(),
+	cronJobLastCompletionDurationChartTmpl.Copy(),
+	cronJobLastCompletedTimeAgoChartTmpl.Copy(),
+	cronJobLastScheduleTimeAgoChartTmpl.Copy(),
+	cronJobSuspendStatusChartTmpl.Copy(),
+	cronJobAgeChartTmpl.Copy(),
+}
+
 var (
 	// CPU resource
 	nodeAllocatableCPURequestsUtilChartTmpl = module.Chart{
@@ -824,8 +847,140 @@ func (c *Collector) addDeploymentCharts(rs *deploymentState) {
 	}
 }
 
-func (c *Collector) removeDeploymentCharts(rs *deploymentState) {
-	prefix := fmt.Sprintf("deployment_%s", replaceDots(rs.id()))
+func (c *Collector) removeDeploymentCharts(st *deploymentState) {
+	prefix := fmt.Sprintf("deployment_%s", replaceDots(st.id()))
+	c.removeCharts(prefix)
+}
+
+var (
+	cronJobJobsCountByStatusChartTmpl = module.Chart{
+		IDSep:    true,
+		ID:       "cronjob_%s.jobs_count_by_status",
+		Title:    "CronJob Jobs Count by Status",
+		Units:    "jobs",
+		Fam:      "cronjob jobs",
+		Ctx:      "k8s_state.cronjob_jobs_count_by_status",
+		Priority: prioCronJobJobsCountByStatus,
+		Dims: module.Dims{
+			{ID: "cronjob_%s_complete_jobs", Name: "completed"},
+			{ID: "cronjob_%s_failed_jobs", Name: "failed"},
+			{ID: "cronjob_%s_running_jobs", Name: "running"},
+			{ID: "cronjob_%s_suspended_jobs", Name: "suspended"},
+		},
+	}
+	cronJobJobsFailedByReasonChartTmpl = module.Chart{
+		IDSep:    true,
+		ID:       "cronjob_%s.jobs_failed_by_reason",
+		Title:    "CronJob Jobs Failed by Reason",
+		Units:    "jobs",
+		Fam:      "cronjob jobs",
+		Ctx:      "k8s_state.cronjob_jobs_failed_by_reason",
+		Priority: prioCronJobJobsFailedByReason,
+		Dims: module.Dims{
+			{ID: "cronjob_%s_failed_jobs_reason_pod_failure_policy", Name: "pod_failure_policy"},
+			{ID: "cronjob_%s_failed_jobs_reason_backoff_limit_exceeded", Name: "backoff_limit_exceeded"},
+			{ID: "cronjob_%s_failed_jobs_reason_deadline_exceeded", Name: "deadline_exceeded"},
+		},
+	}
+	cronJobLastExecutionStatusChartTmpl = module.Chart{
+		IDSep:    true,
+		ID:       "cronjob_%s.last_execution_status",
+		Title:    "CronJob Last Execution Status",
+		Units:    "status",
+		Fam:      "cronjob execution",
+		Ctx:      "k8s_state.cronjob_last_execution_status",
+		Priority: prioCronJobLastExecutionStatus,
+		Dims: module.Dims{
+			{ID: "cronjob_%s_last_execution_status_succeeded", Name: "completed"},
+			{ID: "cronjob_%s_last_execution_status_failed", Name: "failed"},
+		},
+	}
+	cronJobLastCompletionDurationChartTmpl = module.Chart{
+		IDSep:    true,
+		ID:       "cronjob_%s.last_completion_duration",
+		Title:    "CronJob Last Completion Duration",
+		Units:    "seconds",
+		Fam:      "cronjob execution",
+		Ctx:      "k8s_state.cronjob_last_completion_duration",
+		Priority: prioCronJobLastCompletionDuration,
+		Dims: module.Dims{
+			{ID: "cronjob_%s_last_completion_duration", Name: "last_completion"},
+		},
+	}
+	cronJobLastCompletedTimeAgoChartTmpl = module.Chart{
+		IDSep:    true,
+		ID:       "cronjob_%s.last_completed_time_ago",
+		Title:    "CronJob Last Completed Time Ago",
+		Units:    "seconds",
+		Fam:      "cronjob execution",
+		Ctx:      "k8s_state.cronjob_last_completed_time_ago",
+		Priority: prioCronJobLastCompletedTimeAgo,
+		Dims: module.Dims{
+			{ID: "cronjob_%s_last_successful_seconds_ago", Name: "last_completed_ago"},
+		},
+	}
+	cronJobLastScheduleTimeAgoChartTmpl = module.Chart{
+		IDSep:    true,
+		ID:       "cronjob_%s.last_schedule_time_ago",
+		Title:    "CronJob Last Schedule Time Ago",
+		Units:    "seconds",
+		Fam:      "cronjob execution",
+		Ctx:      "k8s_state.cronjob_last_schedule_time_ago",
+		Priority: prioCronJobLastScheduleTimeAgo,
+		Dims: module.Dims{
+			{ID: "cronjob_%s_last_schedule_seconds_ago", Name: "last_schedule_ago"},
+		},
+	}
+	cronJobSuspendStatusChartTmpl = module.Chart{
+		IDSep:    true,
+		ID:       "cronjob_%s.suspend_status",
+		Title:    "CronJob Suspend Status",
+		Units:    "status",
+		Fam:      "cronjob status",
+		Ctx:      "k8s_state.cronjob_suspend_status",
+		Priority: prioCronJobSuspendStatus,
+		Dims: module.Dims{
+			{ID: "cronjob_%s_suspend_status_enabled", Name: "enabled"},
+			{ID: "cronjob_%s_suspend_status_suspended", Name: "suspended"},
+		},
+	}
+	cronJobAgeChartTmpl = module.Chart{
+		IDSep:    true,
+		ID:       "cronjob_%s.age",
+		Title:    "CronJob Age",
+		Units:    "seconds",
+		Fam:      "cronjob age",
+		Ctx:      "k8s_state.cronjob_age",
+		Priority: prioCronJobAge,
+		Dims: module.Dims{
+			{ID: "cronjob_%s_age", Name: "age"},
+		},
+	}
+)
+
+func (c *Collector) addCronJobCharts(st *cronJobState) {
+	charts := cronJobChartsTmpl.Copy()
+
+	for _, chart := range *charts {
+		chart.ID = fmt.Sprintf(chart.ID, replaceDots(st.id()))
+		chart.Labels = []module.Label{
+			{Key: labelKeyClusterID, Value: c.kubeClusterID, Source: module.LabelSourceK8s},
+			{Key: labelKeyClusterName, Value: c.kubeClusterName, Source: module.LabelSourceK8s},
+			{Key: labelKeyCronJobName, Value: st.name, Source: module.LabelSourceK8s},
+			{Key: labelKeyNamespace, Value: st.namespace, Source: module.LabelSourceK8s},
+		}
+		for _, d := range chart.Dims {
+			d.ID = fmt.Sprintf(d.ID, st.id())
+		}
+	}
+
+	if err := c.Charts().Add(*charts...); err != nil {
+		c.Warning(err)
+	}
+}
+
+func (c *Collector) removeCronJobCharts(st *cronJobState) {
+	prefix := fmt.Sprintf("cronjob_%s", replaceDots(st.id()))
 	c.removeCharts(prefix)
 }
 
