@@ -6,6 +6,7 @@ import (
 	"fmt"
 
 	appsv1 "k8s.io/api/apps/v1"
+	batchv1 "k8s.io/api/batch/v1"
 	corev1 "k8s.io/api/core/v1"
 )
 
@@ -21,6 +22,8 @@ const (
 	kubeResourceNode kubeResourceKind = iota + 1
 	kubeResourcePod
 	kubeResourceDeployment
+	kubeResourceCronJob
+	kubeResourceJob
 )
 
 func toNode(i any) (*corev1.Node, error) {
@@ -55,3 +58,25 @@ func toDeployment(i any) (*appsv1.Deployment, error) {
 		return nil, fmt.Errorf("unexpected type: %T (expected %T or %T)", v, &appsv1.Deployment{}, resource(nil))
 	}
 }
+
+func toCronJob(i any) (*batchv1.CronJob, error) {
+	switch v := i.(type) {
+	case *batchv1.CronJob:
+		return v, nil
+	case resource:
+		return toCronJob(v.value())
+	default:
+		return nil, fmt.Errorf("unexpected type: %T (expected %T or %T)", v, &batchv1.CronJob{}, resource(nil))
+	}
+}
+
+func toJob(i any) (*batchv1.Job, error) {
+	switch v := i.(type) {
+	case *batchv1.Job:
+		return v, nil
+	case resource:
+		return toJob(v.value())
+	default:
+		return nil, fmt.Errorf("unexpected type: %T (expected %T or %T)", v, &batchv1.Job{}, resource(nil))
+	}
+}
