@@ -50,6 +50,10 @@ func New() *Collector {
 			},
 		},
 
+		charts: &module.Charts{},
+
+		seenMetrics: make(map[string]bool),
+
 		newSnmpClient: gosnmp.NewHandler,
 
 		checkMaxReps:  true,
@@ -62,9 +66,12 @@ type Collector struct {
 	module.Base
 	Config `yaml:",inline" json:""`
 
+	enableProfiles bool
+
 	vnode *vnodes.VirtualNode
 
-	charts *module.Charts
+	charts      *module.Charts
+	seenMetrics map[string]bool
 
 	newSnmpClient func() gosnmp.Handler
 	snmpClient    gosnmp.Handler
