@@ -21,21 +21,21 @@
 // ----------------------------------------------------------------------------
 // mutex
 
-int __netdata_mutex_init(netdata_mutex_t *mutex) {
+ALWAYS_INLINE int __netdata_mutex_init(netdata_mutex_t *mutex) {
     int ret = pthread_mutex_init(mutex, NULL);
     if(unlikely(ret != 0))
         netdata_log_error("MUTEX_LOCK: failed to initialize (code %d).", ret);
     return ret;
 }
 
-int __netdata_mutex_destroy(netdata_mutex_t *mutex) {
+ALWAYS_INLINE int __netdata_mutex_destroy(netdata_mutex_t *mutex) {
     int ret = pthread_mutex_destroy(mutex);
     if(unlikely(ret != 0))
         netdata_log_error("MUTEX_LOCK: failed to destroy (code %d).", ret);
     return ret;
 }
 
-int __netdata_mutex_lock(netdata_mutex_t *mutex) {
+ALWAYS_INLINE int __netdata_mutex_lock(netdata_mutex_t *mutex) {
     int ret = pthread_mutex_lock(mutex);
     if(unlikely(ret != 0)) {
         netdata_log_error("MUTEX_LOCK: failed to get lock (code %d)", ret);
@@ -46,7 +46,7 @@ int __netdata_mutex_lock(netdata_mutex_t *mutex) {
     return ret;
 }
 
-int __netdata_mutex_trylock(netdata_mutex_t *mutex) {
+ALWAYS_INLINE int __netdata_mutex_trylock(netdata_mutex_t *mutex) {
     int ret = pthread_mutex_trylock(mutex);
     if(ret != 0)
         ;
@@ -56,7 +56,7 @@ int __netdata_mutex_trylock(netdata_mutex_t *mutex) {
     return ret;
 }
 
-int __netdata_mutex_unlock(netdata_mutex_t *mutex) {
+ALWAYS_INLINE int __netdata_mutex_unlock(netdata_mutex_t *mutex) {
     int ret = pthread_mutex_unlock(mutex);
     if(unlikely(ret != 0))
         netdata_log_error("MUTEX_LOCK: failed to unlock (code %d).", ret);
@@ -146,21 +146,21 @@ int netdata_mutex_unlock_debug(const char *file __maybe_unused, const char *func
 // ----------------------------------------------------------------------------
 // rwlock
 
-int __netdata_rwlock_destroy(netdata_rwlock_t *rwlock) {
+ALWAYS_INLINE int __netdata_rwlock_destroy(netdata_rwlock_t *rwlock) {
     int ret = pthread_rwlock_destroy(&rwlock->rwlock_t);
     if(unlikely(ret != 0))
         netdata_log_error("RW_LOCK: failed to destroy lock (code %d)", ret);
     return ret;
 }
 
-int __netdata_rwlock_init(netdata_rwlock_t *rwlock) {
+ALWAYS_INLINE int __netdata_rwlock_init(netdata_rwlock_t *rwlock) {
     int ret = pthread_rwlock_init(&rwlock->rwlock_t, NULL);
     if(unlikely(ret != 0))
         netdata_log_error("RW_LOCK: failed to initialize lock (code %d)", ret);
     return ret;
 }
 
-int __netdata_rwlock_rdlock(netdata_rwlock_t *rwlock) {
+ALWAYS_INLINE int __netdata_rwlock_rdlock(netdata_rwlock_t *rwlock) {
     int ret = pthread_rwlock_rdlock(&rwlock->rwlock_t);
     if(unlikely(ret != 0))
         netdata_log_error("RW_LOCK: failed to obtain read lock (code %d)", ret);
@@ -170,7 +170,7 @@ int __netdata_rwlock_rdlock(netdata_rwlock_t *rwlock) {
     return ret;
 }
 
-int __netdata_rwlock_wrlock(netdata_rwlock_t *rwlock) {
+ALWAYS_INLINE int __netdata_rwlock_wrlock(netdata_rwlock_t *rwlock) {
     int ret = pthread_rwlock_wrlock(&rwlock->rwlock_t);
     if(unlikely(ret != 0))
         netdata_log_error("RW_LOCK: failed to obtain write lock (code %d)", ret);
@@ -180,7 +180,7 @@ int __netdata_rwlock_wrlock(netdata_rwlock_t *rwlock) {
     return ret;
 }
 
-int __netdata_rwlock_rdunlock(netdata_rwlock_t *rwlock) {
+ALWAYS_INLINE int __netdata_rwlock_rdunlock(netdata_rwlock_t *rwlock) {
     int ret = pthread_rwlock_unlock(&rwlock->rwlock_t);
     if(unlikely(ret != 0))
         netdata_log_error("RW_LOCK: failed to release lock (code %d)", ret);
@@ -190,7 +190,7 @@ int __netdata_rwlock_rdunlock(netdata_rwlock_t *rwlock) {
     return ret;
 }
 
-int __netdata_rwlock_wrunlock(netdata_rwlock_t *rwlock) {
+ALWAYS_INLINE int __netdata_rwlock_wrunlock(netdata_rwlock_t *rwlock) {
     int ret = pthread_rwlock_unlock(&rwlock->rwlock_t);
     if(unlikely(ret != 0))
         netdata_log_error("RW_LOCK: failed to release lock (code %d)", ret);
@@ -200,7 +200,7 @@ int __netdata_rwlock_wrunlock(netdata_rwlock_t *rwlock) {
     return ret;
 }
 
-int __netdata_rwlock_tryrdlock(netdata_rwlock_t *rwlock) {
+ALWAYS_INLINE int __netdata_rwlock_tryrdlock(netdata_rwlock_t *rwlock) {
     int ret = pthread_rwlock_tryrdlock(&rwlock->rwlock_t);
     if(ret != 0)
         ;
@@ -210,7 +210,7 @@ int __netdata_rwlock_tryrdlock(netdata_rwlock_t *rwlock) {
     return ret;
 }
 
-int __netdata_rwlock_trywrlock(netdata_rwlock_t *rwlock) {
+ALWAYS_INLINE int __netdata_rwlock_trywrlock(netdata_rwlock_t *rwlock) {
     int ret = pthread_rwlock_trywrlock(&rwlock->rwlock_t);
     if(ret != 0)
         ;
