@@ -523,20 +523,20 @@ static inline int bind_to_this(LISTEN_SOCKETS *sockets, const char *definition,
 int listen_sockets_setup(LISTEN_SOCKETS *sockets) {
     listen_sockets_init(sockets);
 
-    sockets->backlog = (int) appconfig_get_number(sockets->config, sockets->config_section, "listen backlog", sockets->backlog);
+    sockets->backlog = (int) inicfg_get_number(sockets->config, sockets->config_section, "listen backlog", sockets->backlog);
 
     long long int old_port = sockets->default_port;
-    long long int new_port = appconfig_get_number(sockets->config, sockets->config_section, "default port", sockets->default_port);
+    long long int new_port = inicfg_get_number(sockets->config, sockets->config_section, "default port", sockets->default_port);
     if(new_port < 1 || new_port > 65535) {
         nd_log(NDLS_DAEMON, NDLP_ERR,
                "LISTENER: Invalid listen port %lld given. Defaulting to %lld.",
                new_port, old_port);
 
-        sockets->default_port = (uint16_t) appconfig_set_number(sockets->config, sockets->config_section, "default port", old_port);
+        sockets->default_port = (uint16_t) inicfg_set_number(sockets->config, sockets->config_section, "default port", old_port);
     }
     else sockets->default_port = (uint16_t)new_port;
 
-    const char *s = appconfig_get(sockets->config, sockets->config_section, "bind to", sockets->default_bind_to);
+    const char *s = inicfg_get(sockets->config, sockets->config_section, "bind to", sockets->default_bind_to);
     while(*s) {
         const char *e = s;
 
