@@ -2,8 +2,6 @@
 
 #include "uuidmap.h"
 
-#define UUIDMAP_REUSE_GAP 1000
-
 struct uuidmap_entry {
     nd_uuid_t uuid;
     REFCOUNT refcount;
@@ -12,9 +10,7 @@ struct uuidmap_entry {
 struct uuidmap_partition {
     Pvoid_t uuid_to_id;         // JudyL: UUID string -> ID
     Pvoid_t id_to_uuid;         // JudyL: ID -> UUID binary
-    Pvoid_t freed_ids;          // JudyL: the freed IDs
     UUIDMAP_ID next_id;         // Only use lower bits
-    UUIDMAP_ID next_free_id;    // fifo id when reusing freed ids
     RW_SPINLOCK spinlock;
 
     int64_t memory;
@@ -64,33 +60,13 @@ static void uuidmap_init_aral(void) {
 }
 
 static UUIDMAP_ID get_next_id_unsafe(struct uuidmap_partition *partition) {
-    UUIDMAP_ID id = 0;
+    // Check if we've reached the maximum ID value
+    if (unlikely(partition->next_id >= 0x1FFFFFFF))
+        fatal("UUIDMAP: Maximum ID limit reached for partition %u. UUIDs exhausted.",
+              (unsigned int)(partition - uuid_map.p));
 
-    // Try to get a freed ID first if we have enough gap
-    Pvoid_t *PValue;
-    Word_t Index = 0;
-
-    PValue = JudyLFirst(partition->freed_ids, &Index, PJE0);
-    if (PValue && PValue != PJERR && *PValue) {
-        // Check if the stored ID is old enough to be reused
-        UUIDMAP_ID stored_id = *(UUIDMAP_ID *)PValue;
-        UUIDMAP_ID current_next_id = uuidmap_make_id(partition - uuid_map.p, partition->next_id);
-
-        if ((current_next_id - stored_id) >= UUIDMAP_REUSE_GAP) {
-            id = stored_id;
-            // Remove this entry from freed_ids since we're reusing it
-            int rc = JudyLDel(&partition->freed_ids, Index, PJE0);
-            if (unlikely(!rc))
-                fatal("UUIDMAP: cannot delete ID from freed_ids JudyL");
-        }
-    }
-
-    if (id == 0) {
-        // No reusable IDs available, get next sequential ID
-        id = uuidmap_make_id(partition - uuid_map.p, ++partition->next_id);
-    }
-
-    return id;
+    // Simply increment and return the next ID
+    return uuidmap_make_id(partition - uuid_map.p, ++partition->next_id);
 }
 
 static inline UUIDMAP_ID uuidmap_acquire_by_uuid(const nd_uuid_t uuid) {
@@ -220,13 +196,6 @@ void uuidmap_free(UUIDMAP_ID id) {
         if(unlikely(!rc))
             fatal("UUIDMAP: cannot delete ID from JudyL");
 
-        // Add the freed ID to the freed_ids JudyL using next_free_id as index
-        Pvoid_t *PValue = JudyLIns(&uuid_map.p[partition].freed_ids, ++uuid_map.p[partition].next_free_id, PJE0);
-        if (!PValue || PValue == PJERR)
-            fatal("UUIDMAP: corrupted freed_ids JudyL array");
-
-        *(UUIDMAP_ID *)PValue = id;  // Store the actual METRIC_ID as the value
-
         uuid_map.p[partition].memory -= sizeof(*ue);
         uuid_map.p[partition].entries--;
 
@@ -278,6 +247,57 @@ UUIDMAP_ID uuidmap_dup(UUIDMAP_ID id) {
     return id;
 }
 
+size_t uuidmap_destroy(void) {
+    size_t referenced = 0;
+
+    // Traverse all partitions
+    for (size_t partition = 0; partition < UUIDMAP_PARTITIONS; partition++) {
+        // Lock the partition to prevent new entries while we're cleaning up
+        rw_spinlock_write_lock(&uuid_map.p[partition].spinlock);
+
+        Pvoid_t uuid_to_id = uuid_map.p[partition].uuid_to_id;
+        Pvoid_t id_to_uuid = uuid_map.p[partition].id_to_uuid;
+
+        // Process all entries in the id_to_uuid map
+        Word_t id_index = 0;
+        Pvoid_t *id_pvalue;
+
+        for (id_pvalue = JudyLFirst(id_to_uuid, &id_index, PJE0);
+             id_pvalue != NULL && id_pvalue != PJERR;
+             id_pvalue = JudyLNext(id_to_uuid, &id_index, PJE0)) {
+
+            if (!(*id_pvalue))
+                continue;
+
+            struct uuidmap_entry *ue = *id_pvalue;
+
+            // Try to acquire for deletion
+            if (!refcount_acquire_for_deletion(&ue->refcount))
+                referenced++;
+
+            aral_freez(uuid_map.ar, ue);
+        }
+
+        // Free all Judy arrays
+        JudyHSFreeArray(&uuid_to_id, PJE0);
+        JudyLFreeArray(&id_to_uuid, PJE0);
+
+        // Reset partition data
+        memset(&uuid_map.p[partition], 0, sizeof(uuid_map.p[partition]));
+
+        rw_spinlock_write_unlock(&uuid_map.p[partition].spinlock);
+    }
+
+    // Destroy ARAL
+    if (uuid_map.ar) {
+        aral_destroy(uuid_map.ar);
+        uuid_map.ar = NULL;
+    }
+
+    memset(&uuid_map, 0, sizeof(uuid_map));
+    return referenced;
+}
+
 // --------------------------------------------------------------------------------------------------------------------
 
 static volatile bool stop_flag = false;
@@ -564,7 +584,7 @@ int uuidmap_unittest(void) {
         double ops = (double)successful / secs;
 
         fprintf(stderr, "uuidmap_uuid_ptr()   : %.2f ops/sec (%.2f usec/op)\n",
-                ops, (double)(end_ut - start_ut) / successful);
+                ops, (double)(end_ut - start_ut) / (double)successful);
 
         // Second benchmark: uuidmap_get_by_uuid()
         successful = 0;
@@ -583,7 +603,7 @@ int uuidmap_unittest(void) {
         ops = (double)successful / secs;
 
         fprintf(stderr, "uuidmap_acquire_by_uuid(): %.2f ops/sec (%.2f usec/op)\n",
-                ops, (double)(end_ut - start_ut) / successful);
+                ops, (double)(end_ut - start_ut) / (double)successful);
     }
 
     // Phase 2: Delete everything
