@@ -10,6 +10,7 @@ void *operator new(size_t size)
         throw std::bad_alloc();
 
     pulse_ml_memory_allocated(size);
+    workers_memory_call(WORKERS_MEMORY_CALL_LIBC_MALLOC);
     return ptr;
 }
 
@@ -20,6 +21,7 @@ void *operator new[](size_t size)
         throw std::bad_alloc();
 
     pulse_ml_memory_allocated(size);
+    workers_memory_call(WORKERS_MEMORY_CALL_LIBC_MALLOC);
     return ptr;
 }
 
@@ -27,6 +29,7 @@ void operator delete(void *ptr, size_t size) noexcept
 {
     if (ptr) {
         pulse_ml_memory_freed(size);
+        workers_memory_call(WORKERS_MEMORY_CALL_LIBC_FREE);
         free(ptr);
     }
 }
@@ -35,6 +38,7 @@ void operator delete[](void *ptr, size_t size) noexcept
 {
     if (ptr) {
         pulse_ml_memory_freed(size);
+        workers_memory_call(WORKERS_MEMORY_CALL_LIBC_FREE);
         free(ptr);
     }
 }
@@ -42,6 +46,7 @@ void operator delete[](void *ptr, size_t size) noexcept
 void operator delete(void *ptr) noexcept
 {
     if (ptr) {
+        workers_memory_call(WORKERS_MEMORY_CALL_LIBC_FREE);
         free(ptr);
     }
 }
@@ -49,6 +54,7 @@ void operator delete(void *ptr) noexcept
 void operator delete[](void *ptr) noexcept
 {
     if (ptr) {
+        workers_memory_call(WORKERS_MEMORY_CALL_LIBC_FREE);
         free(ptr);
     }
 }
