@@ -85,7 +85,7 @@ static void pluginsd_worker_thread_handle_success(struct plugind *cd) {
 
 static void pluginsd_worker_thread_handle_error(struct plugind *cd, int worker_ret_code) {
     if (worker_ret_code == -1) {
-        netdata_log_info("PLUGINSD: 'host:%s', '%s' (pid %d) was killed with SIGTERM. Disabling it.",
+        netdata_log_info("PLUGINSD: 'host:%s', '%s' (pid %d) exited abnormally. Disabling it.",
              rrdhost_hostname(cd->host), string2str(cd->fullfilename), cd->unsafe.pid);
         plugin_set_disabled(cd);
         return;
@@ -184,7 +184,6 @@ static void *pluginsd_worker_thread(void *arg) {
     spinlock_lock(&cd->unsafe.spinlock);
 
     cd->unsafe.running = false;
-    cd->unsafe.thread = 0;
     cd->unsafe.pid = 0;
 
     POPEN_INSTANCE *pi = cd->unsafe.pi;
@@ -206,8 +205,10 @@ static void pluginsd_main_cleanup(void *pptr) {
     static_thread->enabled = NETDATA_MAIN_THREAD_EXITING;
     netdata_log_info("PLUGINSD: cleaning up...");
 
-    struct plugind *cd;
-    for (cd = pluginsd_root; cd; cd = cd->next) {
+    struct plugind *cd = pluginsd_root;
+    while(cd) {
+        struct plugind *next = cd->next;
+
         spinlock_lock(&cd->unsafe.spinlock);
         if (cd->unsafe.enabled && cd->unsafe.running && cd->unsafe.thread != 0) {
             netdata_log_info("PLUGINSD: 'host:%s', stopping plugin thread: %s",
@@ -215,7 +216,23 @@ static void pluginsd_main_cleanup(void *pptr) {
 
             nd_thread_signal_cancel(cd->unsafe.thread);
         }
+
+        DOUBLE_LINKED_LIST_REMOVE_ITEM_UNSAFE(pluginsd_root, cd, prev, next);
         spinlock_unlock(&cd->unsafe.spinlock);
+
+        if(cd->unsafe.thread) {
+            nd_thread_signal_cancel(cd->unsafe.thread);
+            nd_thread_join(cd->unsafe.thread);
+            cd->unsafe.thread = NULL;
+        }
+
+        string_freez(cd->fullfilename);
+        string_freez(cd->filename);
+        string_freez(cd->id);
+        string_freez(cd->cmd);
+        freez(cd);
+
+        cd = next;
     }
 
     netdata_log_info("PLUGINSD: cleanup completed.");
@@ -313,13 +330,23 @@ void *pluginsd_main(void *ptr) {
 
                 // check if it runs already
                 struct plugind *cd;
-                for (cd = pluginsd_root; cd; cd = cd->next)
-                    if (unlikely(strcmp(string2str(cd->filename), file->d_name) == 0))
+                for (cd = pluginsd_root; cd; cd = cd->next) {
+                    if (unlikely(strcmp(string2str(cd->filename), file->d_name) == 0)) {
                         break;
+                    }
+                }
 
-                if (likely(cd && plugin_is_running(cd))) {
-                    netdata_log_debug(D_PLUGINSD, "plugin '%s' is already running", string2str(cd->filename));
-                    continue;
+                if(cd) {
+                    if (likely(plugin_is_running(cd))) {
+                        netdata_log_debug(D_PLUGINSD, "plugin '%s' is already running", string2str(cd->filename));
+                        continue;
+                    }
+                    else if(cd->unsafe.thread) {
+                        netdata_log_debug(D_PLUGINSD, "plugin '%s' gave up", string2str(cd->filename));
+                        nd_thread_signal_cancel(cd->unsafe.thread);
+                        nd_thread_join(cd->unsafe.thread);
+                        cd->unsafe.thread = NULL;
+                    }
                 }
 
                 // it is not running
@@ -372,7 +399,7 @@ void *pluginsd_main(void *ptr) {
                         snprintfz(tag, NETDATA_THREAD_TAG_MAX, "PD[%s]", pluginname);
 
                         // spawn a new thread for it
-                        cd->unsafe.thread = nd_thread_create(tag, NETDATA_THREAD_OPTION_DEFAULT,
+                        cd->unsafe.thread = nd_thread_create(tag, NETDATA_THREAD_OPTION_DEFAULT | NETDATA_THREAD_OPTION_JOINABLE,
                                                              pluginsd_worker_thread, cd);
                     }
                 }
