@@ -16,7 +16,7 @@ static void jsonwrap_query_metric_plan(BUFFER *wb, QUERY_METRIC *qm) {
     buffer_json_array_close(wb);
 
     buffer_json_member_add_array(wb, "tiers");
-    for (size_t tier = 0; tier < storage_tiers; tier++) {
+    for (size_t tier = 0; tier < nd_profile.storage_tiers; tier++) {
         buffer_json_add_array_item_object(wb);
         buffer_json_member_add_uint64(wb, "tr", tier);
         buffer_json_member_add_time_t(wb, "fe", qm->tiers[tier].db_first_time_s);
@@ -921,7 +921,7 @@ void rrdr_json_wrapper_begin(RRDR *r, BUFFER *wb) {
     buffer_json_member_add_string(wb, "format", rrdr_format_to_string(format));
 
     buffer_json_member_add_array(wb, "db_points_per_tier");
-    for(size_t tier = 0; tier < storage_tiers ; tier++)
+    for(size_t tier = 0; tier < nd_profile.storage_tiers; tier++)
         buffer_json_add_array_item_uint64(wb, qt->db.tiers[tier].points);
     buffer_json_array_close(wb);
 
@@ -1169,7 +1169,6 @@ static void query_target_detailed_objects_tree(BUFFER *wb, RRDR *r, RRDR_OPTIONS
                             }
                             buffer_json_object_close(wb); // contexts
                             buffer_json_object_close(wb); // host
-                            last_host = NULL;
                         }
 
                         buffer_json_member_add_object(wb, host->machine_guid);
@@ -1500,7 +1499,7 @@ void rrdr_json_wrapper_end2(RRDR *r, BUFFER *wb) {
 
     buffer_json_member_add_object(wb, "db");
     {
-        buffer_json_member_add_uint64(wb, "tiers", storage_tiers);
+        buffer_json_member_add_uint64(wb, "tiers", nd_profile.storage_tiers);
         buffer_json_member_add_time_t(wb, "update_every", qt->db.minimum_latest_update_every_s);
         buffer_json_member_add_time_t(wb, "first_entry", qt->db.first_time_s);
         buffer_json_member_add_time_t(wb, "last_entry", qt->db.last_time_s);
@@ -1515,7 +1514,7 @@ void rrdr_json_wrapper_end2(RRDR *r, BUFFER *wb) {
         buffer_json_object_close(wb); // dimensions
 
         buffer_json_member_add_array(wb, "per_tier");
-        for(size_t tier = 0; tier < storage_tiers ; tier++) {
+        for(size_t tier = 0; tier < nd_profile.storage_tiers; tier++) {
             buffer_json_add_array_item_object(wb);
             buffer_json_member_add_uint64(wb, "tier", tier);
             buffer_json_member_add_uint64(wb, "queries", qt->db.tiers[tier].queries);
