@@ -120,7 +120,10 @@ static void claim_add_user_info_command(BUFFER *wb) {
     os_message = "We need to verify this Windows server is yours. So, open a Command Prompt on this server to run the command. It will give you a UUID. Copy and paste this UUID to this box:";
 #else
     os_filename = filename;
-    os_prefix = "sudo cat";
+    if (localhost_is_docker())
+        os_prefix = "docker exec netdata cat";
+    else
+        os_prefix = "sudo cat";
     os_message = "We need to verify this server is yours. SSH to this server and run this command. It will give you a UUID. Copy and paste this UUID to this box:";
 #endif
 
